@@ -21,6 +21,8 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/08/30] メッセージの送信先画像のコピー部分を追加
+ -      [2007/08/30] コミュニティ関連の添付画像エラーを修正
  -      [2007/08/13] 作成
  - ======================================================================== */
 
@@ -70,6 +72,12 @@ class mail_action
      */
     var $attach = null;
 
+    /**
+     * 追加項目設定
+     * @var array
+     */
+    var $addition = array();
+
     /**
      * DB接続オジェクト
      * @var object
@@ -98,6 +106,18 @@ class mail_action
         $this->objdb   = RKT_db::getInstance();
         $this->objfile = RKT_blob::getInstance(BLOB_DRIVER, BLOB_PARAM);
         $this->objimg  = RKT_image::factory(IMAGE_DRIVER);
+
+        $this->addition = array(
+            ACTION_ACT_PHOTO=>     null,            // 会員写真
+            ACTION_DIA_ENTRY=>     null,            // 日記記事
+            ACTION_FRI_MESSAGE=>   null,            // メッセージ
+            ACTION_FRM_TOPIC=>     null,            // フォーラムトピック
+            ACTION_FRM_COMMENT=>   null,            // フォーラムコメント
+            ACTION_COM_COMMUNITY=> 'ref_community', // コミュニティ
+            ACTION_COM_TOPIC=>     'ref_community', // コミュニティトピック
+            ACTION_COM_COMMENT=>   'ref_community', // コミュニティコメント
+        );
+
     }
 
     /**
@@ -312,14 +332,15 @@ class mail_action
      */
 	function manip()
 	{
-        $this->objfile->setUID($this->action['ref_account']);
-
 		$maxrow = count($this->attach_format);
 		for ($row=0; $row<$maxrow; $row++) {
 		    if ($this->is_add_photo()){
                 $this->save_picture($row);
             }
 		} // for ($row=0; $row<$maxrow; $row++)
+		
+        $this->delete_action();
+
         return true;
 	}
 
@@ -377,11 +398,12 @@ class mail_action
      */
     function save_picture($row)
     {
-        if (empty($this->action['ref_community'])){
+        $this->objfile->setUID($this->action['ref_account']);
+        if (empty($this->addition[$this->action['ref_table']])){
             $dir = ARCHIVES_MEMBER_PATH.$this->action['ref_account'].'/';
         } else {
-            $this->objfile->setGID($this->action['ref_community']);
-            $dir = ARCHIVES_COMMUNITY_PATH.$this->action['ref_community'].'/';
+            $this->objfile->setGID($this->action['ref_addition']);
+            $dir = ARCHIVES_COMMUNITY_PATH.$this->action['ref_addition'].'/';
         }
         $temp = md5($this->action['ref_account'].time());
         $filename = substr($temp, rand(0,25), 6);
@@ -418,11 +440,11 @@ class mail_action
             't_height'=>    $small['height'],
         );
 
-        if ($this->insert_picture()){
-            $this->delete_action();
+        if ($this->action['ref_table'] == ACTION_FRI_MESSAGE){
+            $this->to_message_picture($row);
         }
 
-        return true;
+        return $this->insert_picture();
     }
 
     /**
@@ -465,6 +487,7 @@ class mail_action
         );
         $table    = $table[$this->action['ref_table']];
         $relation = $relation[$this->action['ref_table']];
+        $addition = $this->addition[$this->action['ref_table']];
         $status   = $status[$this->action['ref_table']];
         $title    = ($this->action['ref_table'] == ACTION_ACT_PHOTO)?'subject':'title';
 
@@ -483,8 +506,8 @@ class mail_action
         if (!empty($relation)){
             $objmnp->setValue($relation,  $this->action['ref_relation']);
         }
-        if (!empty($relation)){
-            $objmnp->setValue($relation,  $this->action['ref_relation']);
+        if (!empty($addition)){
+            $objmnp->setValue($addition,  $this->action['ref_addition']);
         }
         if (!empty($status)){
             $objmnp->setValue('status',   $status);
@@ -492,6 +515,74 @@ class mail_action
 
         return $objmnp->manip();
     }
+
+    /**
+     * 送信先メッセージ用の添付画像を新規登録
+     *
+     * @access private
+     * @param integer $row
+     * @return boolean  真偽値
+     */
+    function to_message_picture($row)
+    {
+        if (empty($this->action['ref_addition'])){
+            return ;
+        }
+        $sql=
+            'SELECT '.
+                'ref_to '.
+            'FROM '.
+                DB_PREFIX.'fri_message '.
+            'WHERE '.
+                'id = '.$this->action['ref_relation'];
+        $stmt = $this->objdb->prepare($sql); 
+        $stmt->execute(); 
+        $result = $stmt->fetch(PDO_FETCH_ASSOC);
+        $stmt->closeCursor();
+
+        $this->objfile->setUID($result['ref_to']);
+        $dir = ARCHIVES_MEMBER_PATH.$result['ref_to'].'/';
+
+        $temp = md5($result['ref_to'].time());
+        $filename = substr($temp, rand(0,25), 6);
+        $filename = $filename.'.'.$this->attach_format[$row];
+
+        $large_name = $dir.'large/'.$filename;
+        $small_name = $dir.'small/'.$filename;
+
+        /* 大きいサイズの画像 */
+        $this->objimg->setBinary($this->attach[$row], $this->attach_format[$row]);
+        $this->objimg->resize(PHOTO_MAX_SIZE, PHOTO_MAX_SIZE);
+        $large = $this->objimg->getInfo();
+
+        $buffer = $this->objimg->getBinary();
+        $this->objfile->setBuffer($buffer);
+        $this->objfile->save($large_name);
+
+        /* 小さいサイズの画像 */
+        $this->objimg->setBinary($this->attach[$row], $this->attach_format[$row]);
+        $this->objimg->resize(PHOTO_SMALL_SIZE, PHOTO_SMALL_SIZE);
+        $small = $this->objimg->getInfo();
+
+        $buffer = $this->objimg->getBinary();
+        $this->objfile->setBuffer($buffer);
+        $this->objfile->save($small_name);
+
+        $objmnp = new RKT_manip($this->objdb, DB_PREFIX.'fri_picture');
+
+        $objmnp->setValue('modify',      date('Y-m-d H:i:s'));        
+        $objmnp->setValue('ref_account', $result['ref_to']);
+        $objmnp->setValue('ref_message', $this->action['ref_addition']);
+        $objmnp->setValue('title',       $filename);
+        $objmnp->setValue('filename',    $large_name);
+        $objmnp->setValue('width',       $large['width']);
+        $objmnp->setValue('height',      $large['height']);
+        $objmnp->setValue('thumbnail',   $small_name);
+        $objmnp->setValue('t_width',     $small['width']);
+        $objmnp->setValue('t_height',    $small['height']);
+
+        return $objmnp->manip();
+    }
 } // mail_action
 
 $objmac = new mail_action();
