@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/08/19] アクションページの追加
  -      [2006/08/22] 作成
  - ======================================================================== */
 
@@ -56,7 +57,7 @@ function __session_start()
 }
 
 /**
- * ログイン処理
+ * ﾛｸﾞｲﾝ処理
  *
  * @access public
  * @param reference $group
@@ -108,108 +109,51 @@ function __controller()
     $page   = empty($args[3])?$module:$args[3];
 
     __session_start();                      // セッションの開始
-    __login_action($group,$module,$page);   // ログイン処理
+    __login_action($group,$module,$page);   // ﾛｸﾞｲﾝ処理
 
     $titles = array (
-        'admin'=>   array(
-            'account'=>     array(      // アカウント管理
-                'exit'=>        '退会処理',
-                'mails'=>       'メール配信',
-                'profile'=>     'プロフィール',
-                'result'=>      '会員検索結果',
-                'search'=>      '会員検索',
-                'sendmail'=>    '配信メール送信',
-            ),
-            'design'=>      array(      // デザイン設定
-                'css'=>         'スタイルシート編集',
-                'design'=>      'デザイン設定',
-                'list'=>        'テーマ一覧',
-                'preview'=>     'デザイン画像表示',
-                'theme'=>       'デザインテーマ編集',
-                'upload'=>      'テーマ素材アップロード',
-            ),
-            'environment'=> array(      // 環境設定
-                'account'=>     'スタイルシート編集',
-                'config'=>      'デザイン設定',
-            ),
-            'inquire'=>     array(      // お問合せ
-                'list'=>        '問合せ一覧',
-                'sendmail'=>    '問合せ返信メール',
-            ),
-            'item'=>        array(      // コンテンツ記事
-                'category'=>    'コンテンツカテゴリ',
-                'image_list'=>  'TinyMCE用画像リスト',
-                'item'=>        'コンテンツ記事編集',
-                'link_list'=>   'TinyMCE用リンクリスト',
-                'list'=>        'コンテンツ記事一覧',
-                'options'=>     '質問選択肢',
-                'upload'=>      'コンテンツ添付ファイルアップロード',
-            ),
-            'mail'=>        array(      // 配信メールテンプレート
-                'list'=>        '自動メール定型文一覧',
-                'mail'=>        '自動メール定型文'
-             ),
-            'master'=>      array(      // マスターテーブル
-                'com_category'=>'コミュニティカテゴリ',
-                'com_genre'=>   'コミュニティジャンル',
-                'frm_category'=>'フォーラムカテゴリ',
-                'frm_genre'=>   'フォーラムジャンル',
-                'inquire'=>     '問合せカテゴリ',
-                'married'=>     '結婚マスター',
-                'review'=>      'レビューカテゴリ',
-                'sys_sort'=>    '各一覧ページ並び順(ORDER BY句)定義'
-             ),
-            'profile'=>     array(      // プロフィール
-                'enquete'=>     'プロフィール追加項目編集',
-                'enquetes'=>    'プロフィール項目一覧',
-                'items'=>       'アンケート選択肢一覧',
-            ),
-            'sponsor'=>     array(      // スポンサー
-                'list'=>        'スポンサーバナー一覧',
-                'sponsor'=>     'スポンサーバナー編集',
-            ),
-        ), /* 管理者ページ */
         'community'=>   array(
-            'bbs'=>         array(      // トピック、イベント
-                'browse'=>      'トピック参照',
-                'comment'=>     'コメントを書き込む',
-                'entrys'=>      'イベント参加メンバー一覧',
-                'event'=>       '新しいイベントを作成する',
-                'list'=>        'トピック一覧',
-                'send'=>        'イベント参加者へメッセージ送信',
-                'topic'=>       '新しいトピックを作成する',
+            'bbs'=>         array(      // ﾄﾋﾟｯｸ、ｲﾍﾞﾝﾄ
+                'browse'=>      'ﾄﾋﾟｯｸ参照',
+                'comment'=>     'ｺﾒﾝﾄを書き込む',
+                'entrys'=>      'ｲﾍﾞﾝﾄ参加ﾒﾝﾊﾞｰ一覧',
+                'event'=>       '新しいｲﾍﾞﾝﾄを作成する',
+                'list'=>        'ﾄﾋﾟｯｸ一覧',
+                'send'=>        'ｲﾍﾞﾝﾄ参加者へﾒｯｾｰｼﾞ送信',
+                'topic'=>       '新しいﾄﾋﾟｯｸを作成する',
             ),
             'edit'=>        array(      // 各種編集
-                'community'=>   'コミュニティ基礎情報',
-                'entry'=>       'コミュニティに参加',
-                'exit'=>        'コミュニティの退会',
+                'community'=>   'ｺﾐｭﾆﾃｨ基礎情報',
+                'entry'=>       'ｺﾐｭﾆﾃｨに参加',
+                'exit'=>        'ｺﾐｭﾆﾃｨの退会',
                 'intro'=>       '友達に紹介する',
-                'names'=>       'コミュニティ参加名簿',
+                'names'=>       'ｺﾐｭﾆﾃｨ参加名簿',
             ),
-            'item'=>        array(      // コミュニティ記事
-                'browse'=>      'コミュニティ記事閲覧',
-                'comment'=>     'コメント',
-                'comments'=>    'コメント一覧',
-                'item'=>        'コミュニティ記事',
-                'question'=>    'アンケート結果',
+            'item'=>        array(      // ｺﾐｭﾆﾃｨ記事
+                'browse'=>      'ｺﾐｭﾆﾃｨ記事閲覧',
+                'comment'=>     'ｺﾒﾝﾄ',
+                'comments'=>    'ｺﾒﾝﾄ一覧',
+                'item'=>        'ｺﾐｭﾆﾃｨ記事',
+                'question'=>    'ｱﾝｹｰﾄ結果',
             ),
-            'search'=>      array(      // コミュニティ検索
-                'event'=>       'イベント検索結果',
-                'result'=>      'コミュニティ検索結果',
-                'schedule'=>    'イベント検索',
-                'search'=>      'コミュニティ検索',
+            'search'=>      array(      // ｺﾐｭﾆﾃｨ検索
+                'event'=>       'ｲﾍﾞﾝﾄ検索結果',
+                'result'=>      'ｺﾐｭﾆﾃｨ検索結果',
+                'schedule'=>    'ｲﾍﾞﾝﾄ検索',
+                'search'=>      'ｺﾐｭﾆﾃｨ検索',
             ),
-            'show'=>        array(      // コミュニティ情報閲覧
-                'calendar'=>    'コミュニティイベントカレンダー',
-                'community'=>   'コミュニティ情報',
-                'member'=>      'メンバー一覧',
-                'menu'=>        'コミュニティメニュー',
+            'show'=>        array(      // ｺﾐｭﾆﾃｨ情報閲覧
+                'calendar'=>    'ｺﾐｭﾆﾃｨｲﾍﾞﾝﾄｶﾚﾝﾀﾞｰ',
+                'community'=>   'ｺﾐｭﾆﾃｨ情報',
+                'home'=>        'ﾎｰﾑ',
+                'member'=>      'ﾒﾝﾊﾞｰ一覧',
+                'menu'=>        'ｺﾐｭﾆﾃｨメニュー',
             ),
-        ), /* コミュニティページ */
+        ), /* ｺﾐｭﾆﾃｨページ */
         'friend'=>   array(
             'diary'=>       array(      // 友達日記
-                'comment'=>     'コメントを書く',
-                'comments'=>    'コメント一覧',
+                'comment'=>     'ｺﾒﾝﾄを書く',
+                'comments'=>    'ｺﾒﾝﾄ一覧',
                 'entry'=>       '日記',
                 'list'=>        '日記一覧',
                 'result'=>      '日記検索結果',
@@ -218,115 +162,118 @@ function __controller()
             'edit'=>        array(      // 各種編集
                 'favorite'=>    'お気に入り追加',
                 'intro'=>       '紹介文編集',
-                'message'=>     'メッセージを送る',
+                'message'=>     'ﾒｯｾｰｼﾞを送る',
                 'relation'=>    '友達追加',
             ),
             'forum'=>       array(      // フォーラム
-                'browse'=>      'トピック参照',
-                'comment'=>     'コメントを書き込む',
-                'list'=>        'トピック一覧',
-                'result'=>      'トピック検索結果',
-                'search'=>      'トピック検索',
+                'browse'=>      'ﾄﾋﾟｯｸ参照',
+                'comment'=>     'ｺﾒﾝﾄを書き込む',
+                'list'=>        'ﾄﾋﾟｯｸ一覧',
+                'result'=>      'ﾄﾋﾟｯｸ検索結果',
+                'search'=>      'ﾄﾋﾟｯｸ検索',
             ),
             'search'=>      array(      // 友達検索
                 'result'=>      '友達検索結果',
                 'search'=>      '友達検索',
             ),
             'show'=>        array(      // 友達情報閲覧
-                'community'=>   'コミュニティ一覧',
+                'community'=>   'ｺﾐｭﾆﾃｨ一覧',
                 'friends'=>     '友達一覧',
+                'home'=>        'ﾎｰﾑ',
                 'intro'=>       '紹介文一覧',
                 'menu'=>        'お友達メニュー',
                 'photo'=>       '写真一覧',
-                'profile'=>     'プロフィール',
+                'profile'=>     'ﾌﾟﾛﾌｨｰﾙ',
                 'recent'=>      '各種一覧表示',
-                'review'=>      '投稿レビュー一覧表示',
+                'review'=>      '投稿ﾚﾋﾞｭｰ一覧表示',
             ),
          ), /* 友達ページ */
         'private'=>   array(
             'account'=>     array(      // 会員情報
                 'account'=>     '会員基礎情報',
-                'autologin'=>   '自動ログイン登録',
+                'autologin'=>   '自動ﾛｸﾞｲﾝ登録',
                 'exit'=>        '退会処理',
-                'passwd'=>      'パスワード変更',
+                'passwd'=>      'ﾊﾟｽﾜｰﾄﾞ変更',
             ),
-            'content'=>     array(      // コンテンツ閲覧
-                'browse'=>      'コンテンツ記事閲覧',
-                'inquire'=>     '問合せフォーム',
+            'content'=>     array(      // ｺﾝﾃﾝﾂ閲覧
+                'browse'=>      'ｺﾝﾃﾝﾂ記事閲覧',
+                'inquire'=>     '問合せﾌｫｰﾑ',
                 'list'=>        'お知らせ一覧',
-                'question'=>    'アンケート結果',
+                'question'=>    'ｱﾝｹｰﾄ結果',
             ),
             'diary'=>       array(      // 日記
                 'category'=>    'カテゴリ',
-                'comment'=>     'コメントを書く',
-                'comments'=>    'コメント一覧',
+                'comment'=>     'ｺﾒﾝﾄを書く',
+                'comments'=>    'ｺﾒﾝﾄ一覧',
                 'diary'=>       '日記設定',
                 'entry'=>       '記事閲覧',
                 'list'=>        '日記一覧',
                 'post'=>        '日記記事投稿',
             ),
             'edit'=>        array(      // 各種編集
-                'community'=>   '参加コミュニティ一覧',
-                'friend'=>      '友達リスト管理',
+                'community'=>   '参加ｺﾐｭﾆﾃｨ一覧',
+                'friend'=>      '友達ﾘｽﾄ管理',
                 'photo'=>       '写真編集',
-                'profile'=>     'プロフィール編集',
+                'profile'=>     'ﾌﾟﾛﾌｨｰﾙ編集',
                 'relation'=>    '各種認証',
-                'schedule'=>    'スケジュール編集',
+                'schedule'=>    'ｽｹｼﾞｭｰﾙ編集',
             ),
             'forum'=>       array(      // フォーラム
-                'browse'=>      'トピック閲覧',
-                'comment'=>     'コメントを書き込む',
-                'list'=>        'トピック一覧',
+                'browse'=>      'ﾄﾋﾟｯｸ閲覧',
+                'comment'=>     'ｺﾒﾝﾄを書き込む',
+                'list'=>        'ﾄﾋﾟｯｸ一覧',
                 'response'=>    '返事を書く',
-                'topic'=>       'トピック編集',
+                'topic'=>       'ﾄﾋﾟｯｸ編集',
             ),
-            'home'=>        array(      // Myホーム
-                'home'=>        'Myホーム',
-                'menu'=>        'Myホーム',
-                'invite'=>      '友達招待フォーム',
+            'home'=>        array(      // Myﾎｰﾑ
+                'home'=>        'Myﾎｰﾑ',
+                'menu'=>        'Myﾎｰﾑ',
+                'mail_action'=> 'ﾒｰﾙ画像添付反映',
+                'invite'=>      '友達招待ﾌｫｰﾑ',
                 'search'=>      '各種検索',
+                'recent'=>      '各種一覧表示',
             ),
-            'message'=>     array(      // メッセージ
-                'browse'=>      'メッセージ閲覧',
-                'list'=>        'メッセージボックス',
-                'send'=>        'メッセージを送る',
+            'message'=>     array(      // ﾒｯｾｰｼﾞ
+                'browse'=>      'ﾒｯｾｰｼﾞ閲覧',
+                'list'=>        'ﾒｯｾｰｼﾞﾎﾞｯｸｽ',
+                'send'=>        'ﾒｯｾｰｼﾞを送る',
             ),
-            'review'=>      array(      // レビュー
-                'browse'=>      '商品レビュー閲覧',
-                'item'=>        'レビュー対象商品検索',
-                'list'=>        '投稿レビュー一覧表示',
-                'post'=>        'レビュー投稿',
-                'search'=>      '投稿レビュー検索',
+            'review'=>      array(      // ﾚﾋﾞｭｰ
+                'browse'=>      '商品ﾚﾋﾞｭｰ閲覧',
+                'item'=>        'ﾚﾋﾞｭｰ対象商品検索',
+                'list'=>        '投稿ﾚﾋﾞｭｰ一覧表示',
+                'post'=>        'ﾚﾋﾞｭｰ投稿',
+                'search'=>      '投稿ﾚﾋﾞｭｰ検索',
             ),
             'show'=>        array(      // 各種閲覧
-                'calendar'=>    'カレンダー',
+                'calendar'=>    'ｶﾚﾝﾀﾞｰ',
                 'favorite'=>    'お気に入り',
                 'footprint'=>   'あしあと',
                 'friends'=>     '友達一覧',
                 'intro'=>       '紹介文一覧',
-                'profile'=>     'プロフィール確認',
-                'schedule'=>    'スケジュール確認',
+                'profile'=>     'ﾌﾟﾛﾌｨｰﾙ確認',
+                'schedule'=>    'ｽｹｼﾞｭｰﾙ確認',
             ),
         ), /* プライベートページ */
         'public'=>   array(
-            'content'=>     array(      // コンテンツ記事
-                'browse'=>      'コンテンツ記事閲覧',
+            'content'=>     array(      // ｺﾝﾃﾝﾂ記事
+                'browse'=>      'ｺﾝﾃﾝﾂ記事閲覧',
                 'default'=>     WAP_SYSTEM_NAME,
-                'inquire'=>     '問合せフォーム',
+                'inquire'=>     '問合せﾌｫｰﾑ',
             ),
-            'login'=>       array(      // ログイン
-                'entrance'=>    'ログインフォーム',
-                'exit'=>        '退会ページ',
-                'login'=>       'ログイン',
-                'logout'=>      'ログアウト',
-                'reissue'=>     'パスワードの再発行',
+            'login'=>       array(      // ﾛｸﾞｲﾝ
+                'entrance'=>    'ﾛｸﾞｲﾝﾌｫｰﾑ',
+                'exit'=>        '退会ﾍﾟｰｼﾞ',
+                'login'=>       'ﾛｸﾞｲﾝ',
+                'logout'=>      'ﾛｸﾞｱｳﾄ',
+                'reissue'=>     'ﾊﾟｽﾜｰﾄﾞの再発行',
             ),
             'registry'=>    array(      // 会員登録
-                'account'=>     '会員登録フォーム',
+                'account'=>     '会員登録ﾌｫｰﾑ',
                 'confirm'=>     '入力内容確認',
-                'invite'=>      '自動招待フォーム',
+                'invite'=>      '自動招待ﾌｫｰﾑ',
                 'registry'=>    '会員登録',
-                'sendmail'=>    '会員登録確認メール発送',
+                'sendmail'=>    '会員登録確認ﾒｰﾙ発送',
             ),
         ), /* 一般公共ページ */
     );
@@ -345,7 +292,6 @@ function __controller()
 
     header('Content-Type: text/html; charset=Shift_JIS');
     $obj_webapp = new webapp();
-    $obj_webapp->setTemplateBase('base.tpl');
     $obj_webapp->baseAssign('title', $titles[$group][$module][$page]);
     $obj_webapp->execute();
     $obj_webapp->display();
