@@ -24,13 +24,17 @@ CrossEditor.prototype = {
 	},
 	createMenu: function(){
 
-		var cmds = ['undo',
-		'redo',
-		'fontsize',
-		'bold',
-		'underline',
-		'forecolor',
-		'removeformat' ];
+		var cmds = [
+			'undo',
+			'redo',
+			'fontsize',
+			'bold',
+			'underline',
+			'forecolor',
+			'removeformat',
+			'createlink',
+			'unlink'
+		];
 
 		var alts = {
 			'undo':'元に戻す',
@@ -39,7 +43,9 @@ CrossEditor.prototype = {
 			'bold':'太字',
 			'underline':'下線',
 			'forecolor':'文字の色',
-			'removeformat':'取り消し'
+			'removeformat':'修飾の取り消し',
+			'createlink':'リンク',
+			'unlink':'リンクの取り消し'
 		};
 
 
@@ -50,11 +56,11 @@ CrossEditor.prototype = {
 			icon.alt = alts[cmd];
 			menu.appendChild(icon);
 
-			if(cmd=='forecolor'){
+			if (cmd=='forecolor'){
 				menu.id = 'pallete_button';
 				$('menu').appendChild(menu);
 				return;
-			} else if(cmd=='fontsize'){
+			} else if (cmd=='fontsize'){
 				this.createSelect();
 			}
 			var opt = false;
@@ -71,6 +77,11 @@ CrossEditor.prototype = {
 		try{
 			if (cmd=='fontsize'){
 				opt = $('fsize').selectedIndex + 1;
+			} else if (cmd=='createlink'){
+			    opt = prompt('URLを入力:', 'http://');
+			    if (opt == null) {
+			    	return;
+			  	}
 			}
 			this.doc.execCommand(cmd, false, opt);
 		}catch(e){
@@ -210,6 +221,7 @@ function insertImg(src){
 
 	$('edit').contentWindow.document.body.innerHTML = body;
 }
+
 function insertEmoji(src){
 	var body = $('edit').contentWindow.document.body.innerHTML.toString();
 	body += '<img src="'+ src +'" class="emoji">';
