@@ -100,8 +100,9 @@ class BLOB_db extends BLOB_common
      */
     function save($filename)
     {
-        $this->origin = md5($filename);
-        $this->name   = basename($filename);
+        $this->origin    = md5($filename);
+        $this->name      = basename($filename);
+        $this->mime_type = $this->get_mime_type($filename);
         $values = array(
             'modify'=>    $this->objdb->quote(date('Y-m-d H:i:s')),
             'origin'=>    $this->objdb->quote($this->origin),
