@@ -16,6 +16,7 @@
  -      ImageMagickを使用しています。以下などから取り寄せてください。
  -      http://www.imagemagick.org/script/download.php
  - 更新履歴：
+ -      [2007/06/24] RKT_imagemagick::resize()の$exactly名間違い修正
  -      [2006/06/04] RKT_imagemagick::setBinary()とRKT_imagemagick::getInfo()を追加
  -      [2006/06/01] 作成
  - ======================================================================== */
@@ -194,6 +195,10 @@ class RKT_imagemagick
      */
     function identify($param)
     {
+        if (empty($this->buffer)){
+            return false;
+        }
+
         $command = '"'.IMAGEMAGICK_PATH.'identify" '.$param;
         $descriptorspec = array(
             0 => array('pipe', 'r'),
@@ -483,7 +488,7 @@ class RKT_imagemagick
     function resize($width, $height, $exactly=false)
     {
         if ($this->infos['width'] < $width &&
-            $this->infos['height'] < $height && !$large){
+            $this->infos['height'] < $height && !$exactly){
             return ;
         }
 
