@@ -13,6 +13,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/
  - 更新履歴：
+ -      [2007/06/08]    全テーブル名の取得関数追加
  -      [2007/03/11]    入力データのエスケープ処理指定を追加
  -      [2005/06/01]    コンストラクタ引数変更、DB接続オジェクトを追加
  -      [2005/05/11]    作成
@@ -38,13 +39,13 @@ class manip_mysql
      * テーブル名
      * @var string
      */
-    var $tbl_name = "";
+    var $tbl_name = '';
 
     /**
-     * テーブル名
-     * @var string
+     * プライマリキー
+     * @var array
      */
-    var $primary_key = "";
+    var $primary = array();
 
     /**
      * コンストラクタ
@@ -60,6 +61,18 @@ class manip_mysql
         $this->tbl_name = $tbl_name;
     }
 
+    /**
+     * テーブル名の設定
+     *
+     * @access public
+     * @param string $tbl_name
+     * @return void
+     */
+    function setTableName($tbl_name)
+    {
+        $this->tbl_name = $tbl_name;
+    }
+
     /**
      * プライマリキーの取得
      *
@@ -68,7 +81,27 @@ class manip_mysql
      */
     function getPrimaryKey()
     {
-        return $this->primary_key;
+        return $this->primary['key'];
+    }
+
+    /**
+     * 全テーブル名の取得
+     *
+     * @access public
+     * @return array
+     */
+    function getTables()
+    {
+        $stmt = $this->objdb->prepare('SHOW TABLES'); 
+        $stmt->execute(); 
+        $result = $stmt->fetchAll(PDO_FETCH_NUM);
+
+        $list = array();
+        foreach ($result as $value){
+            $list[] = $value[0];
+        }
+
+        return $list;
     }
 
     /**
@@ -80,7 +113,6 @@ class manip_mysql
      */
     function parseColumns($skip=array())
     {
-        $result = null;
         $sql=
             'SHOW '.
                 'COLUMNS '.
@@ -96,6 +128,7 @@ class manip_mysql
             $parse = $this->parse_type($value['Type'],$key);
             $infos = array(
                 'type'=>    $parse['type'],
+                'pdo_type'=>$parse['pdo_type'],
                 'option'=>  $parse['option'],
                 'required'=>$this->parse_required($value['Null']),
                 'effect'=>  array('RKT_validate', 'escape_character'),
@@ -103,7 +136,7 @@ class manip_mysql
 
             /* プライマリキーは別扱い */
             if ($this->is_primary_key($value['Key'])){
-                $this->primary_key = array(
+                $this->primary = array(
                     'key'=>  $key,
                     'info'=> $infos
                 );
@@ -127,7 +160,8 @@ class manip_mysql
      */
     function parse_type($subject,$field)
     {
-        $type = 'number';
+        $type = 'string';
+        $pdo_type = PDO_PARAM_STR;
         $option = null;
         $size = 8000;
         if (preg_match("/\d+/i",$subject,$matchs)){
@@ -142,6 +176,7 @@ class manip_mysql
             );
         } else if (preg_match("/int/i",$subject)){
             $type = 'number';
+            $pdo_type = PDO_PARAM_INT;
         } else if (preg_match("/text/i",$subject)){
             $type = 'string';
             $option = array(
@@ -159,16 +194,19 @@ class manip_mysql
             );
         } else if (preg_match("/float/i",$subject)){
             $type = 'number';
+            $pdo_type = PDO_PARAM_INT;
             $option = array(
                 'decimal'=>'.'
             );
         } else if (preg_match("/double/i",$subject)){
             $type = 'number';
+            $pdo_type = PDO_PARAM_INT;
             $option = array(
                 'decimal'=>'.'
             );
         } else if (preg_match("/blob/i",$subject)){
             $type = 'string';
+            $pdo_type = PDO_PARAM_LOB;
             $option = array(
                 'max_length'=>$size
             );
@@ -203,7 +241,7 @@ class manip_mysql
             );
         }
         
-        return array('type'=>$type, 'option'=>$option);
+        return array('type'=>$type, 'pdo_type'=>$pdo_type, 'option'=>$option);
     }
 
     /**
