@@ -13,6 +13,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/
  - 更新履歴：
+ -      [2007/08/19] 削除判定変数の追加
  -      [2007/08/05] 挿入又は更新操作の実行manip()関数を追加
  -      [2007/03/11] 入力データのエスケープ処理をRKT_validateへ移行
  -      [2006/05/19] privateの関数をpublickに変更（query関連）
@@ -224,14 +225,16 @@ class RKT_manip extends RKT_validate
      */
     function execute(&$objhtml, $skip=null, $validates=null)
     {
-        $is_manip   = preg_match('/manip/i',$_SERVER['REQUEST_URI']);
-        $is_confirm = preg_match('/confirm/i',$_SERVER['REQUEST_URI']);
+        $is_manip    = preg_match('/manip/i',$_SERVER['REQUEST_URI']);
+        $is_confirm  = preg_match('/confirm/i',$_SERVER['REQUEST_URI']);
         $is_complete = preg_match('/complete/i',$_SERVER['REQUEST_URI']);
+        $is_deleted  = preg_match('/deleted/i',$_SERVER['REQUEST_URI']);
 
         $manip = array(
             'edit'=>     empty($is_confirm),
             'complete'=> !empty($is_complete),
             'action'=>   empty($is_confirm)?'edit':'manip',
+            'deleted'=>  !empty($is_deleted),
         );
         $objhtml->Assign('manip', $manip);
         
