@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/08/30] あしあとの更新処理にrkt_manipクラスを使用
  -      [2007/08/19] BASEテンプレートの読み込みを変更
  -      [2007/07/05] 絵文字コンバートで文字コードの変更はなし
  -      [2007/06/17] コミュニティ：トピック、イベント、記事、アンケート権限追加
@@ -32,6 +33,7 @@
  - ======================================================================== */
 
 require_once LIB_DIR.'rkt_db.php';
+require_once LIB_DIR.'rkt_manip.php';
 require_once LIB_DIR.'rkt_validate.php';
 require_once LIB_DIR.'rkt_auth.php';
 require_once LIB_DIR.'rkt_webapp.php';
@@ -326,28 +328,17 @@ class WAP_community extends RKT_webapp
         $result = $stmt->fetch(PDO_FETCH_ASSOC);
         $stmt->closeCursor();
 
+        /* テーブルの更新処理 */
+        $objmnp = new RKT_manip($this->objdb, DB_PREFIX.'com_footprint');
         if (empty($result['id'])){
-            $sql =
-                'INSERT INTO '.
-                    DB_PREFIX.'com_footprint('.
-                        'modify,'.
-                        'ref_community,'.
-                        'ref_account '.
-                    ') VALUES ('.
-                        "'".date('Y-m-d H:i:s')."',".
-                        $this->ref_community.','.
-                        $this->account['id'].
-                    ')';
+            $objmnp->setValue('ref_community',  $this->ref_community);
+            $objmnp->setValue('ref_account',    $this->account['id']);
         } else {
-            $sql =
-                'UPDATE '.
-                    DB_PREFIX.'com_footprint '.
-                'SET '.
-                    "modify = '".date('Y-m-d H:i:s')."' ".
-                'WHERE '.
-                    'id='.$result['id'];
+            $objmnp->setCurID($result['id']);
         }
-        return $this->objdb->exec($sql);
+        $objmnp->setValue('modify', date('Y-m-d H:i:s'));
+
+        return $objmnp->manip();
     }
 
     /**
@@ -373,21 +364,15 @@ class WAP_community extends RKT_webapp
         $stmt->closeCursor();
 
         if (empty($result['ct'])){
-            $unique = 1;
-            $sql=
-                'INSERT INTO '.
-                    DB_PREFIX.'com_accesslog('.
-                        'modify,'.
-                        'ref_community,'.
-                        'ref_account,'.
-                        'unique_flag '.
-                    ') VALUES ('.
-                        "'".date('Y-m-d H:i:s')."',".
-                        $this->ref_community.','.
-                        $this->account['id'].','.
-                        "'".$unique."'".
-                    ')';
-            $this->ins_accesslog = $this->objdb->exec($sql);
+            /* テーブルの更新処理 */
+            $objmnp = new RKT_manip($this->objdb, DB_PREFIX.'com_accesslog');
+
+            $objmnp->setValue('modify',         date('Y-m-d H:i:s'));
+            $objmnp->setValue('ref_community',  $this->ref_community);
+            $objmnp->setValue('ref_account',    $this->account['id']);
+            $objmnp->setValue('unique_flag',    AVAIL_ENABLE);
+
+            $this->ins_accesslog = $objmnp->manip();
         }
     }
 
