@@ -375,14 +375,15 @@ class webapp extends WAP_community
         if (empty($this->attach)){
             return false;
         }
-        $ref_relation = $this->objmnp->getCurID();
+        $ref_community = $this->objmnp->getCurID();
 
         $objmnp = new RKT_manip($this->objdb, DB_PREFIX.'act_mailaction');
 
         $objmnp->setValue('modify',        date('Y-m-d H:i:s'));
         $objmnp->setValue('ref_table',     ACTION_COM_COMMUNITY);
-        $objmnp->setValue('ref_relation',  $ref_relation);
+        $objmnp->setValue('ref_relation',  0);
         $objmnp->setValue('ref_account',   $this->account['id']);
+        $objmnp->setValue('ref_addition',  $ref_community);
 
         return $objmnp->manip();
     }
