@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/08/11] メンバー削除時に会員数を更新するように修正
  -      [2007/02/12] コミュニティメンバーステータスをビットフラグに変更
  -      [2006/07/10] 作成
  - ======================================================================== */
@@ -77,6 +78,7 @@ class webapp extends WAP_community
 
         /* 削除 */
         if ($this->delete_names()){
+            $this->update_total();
             header('Location: '.HTTP_ACTION.'community/edit/names/'.$this->sid.'/'.$this->ref_community.'/'.WAP_URI_SEPARATOR.'updated=1');
             exit();
         }
@@ -199,6 +201,38 @@ class webapp extends WAP_community
         return $this->objdb->exec($sql);
     }
 
+    /**
+     * 会員総数を更新
+     *
+     * @access private
+     * @return void
+     */
+    function update_total()
+    {
+        $sql = 
+            'SELECT '.
+                'count(id) as total '.
+            'FROM '.
+                DB_PREFIX.'com_names '.
+            'WHERE '.
+                'ref_community = '.$this->ref_community. ' AND '.
+                sql_query::bitFlag('status & '.STATUS_COMMUNITY_MEMBERS);
+        $stmt = $this->objdb->prepare($sql); 
+        $stmt->execute(); 
+        $result = $stmt->fetch(PDO::FETCH_ASSOC);
+        $stmt->closeCursor();
+        $total = empty($result['total'])?0:$result['total'];
+
+        $sql =
+            'UPDATE '.
+                DB_PREFIX.'com_community '.
+            'SET '.
+                'total = '.$total.' '.
+            'WHERE '.
+                'id = '.$this->ref_community;
+        $this->objdb->exec($sql);
+    }
+
     /**
      * 管理人の交代申請
      *
