@@ -227,7 +227,8 @@ class webapp extends WAP_community
                 'opt.ref_community = '.$this->ref_community.' AND '.
                 'opt.ref_topic = '.$this->ref_topic.' '.
             'GROUP BY '.
-                'opt.id '.
+                'opt.id,'.
+                'opt.item '.
             'ORDER BY '.
                 'vote DESC';
         $stmt = $this->objdb->prepare($sql); 
