@@ -189,7 +189,16 @@ class webapp extends WAP_private
 
         /* GROUP BY */
         if (!empty($this->table)){
-            $this->group = 'GROUP BY com.id ';
+            $this->group = 
+                'GROUP BY '.
+                    'com.id,'.
+                    'com.community,'.
+                    'com.total,'.
+                    'com.publicity,'.
+                    'prf.prefecture,'.
+                    'pic.thumbnail,'.
+                    'pic.t_width,'.
+                    'pic.t_height ';
         }
 
         /* 並び替え */
