@@ -21,6 +21,8 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/08/30] 画像添付時の送信先IDを格納
+ -      [2007/08/30] メッセージの更新処理にrkt_manipクラスを使用
  -      [2007/08/19] メールによる画像添付機能追加
  -      [2007/03/08] 下書き時にも自動通知メールが送信されるエラーを修正
  -      [2006/07/10] 作成
@@ -53,6 +55,12 @@ class webapp extends WAP_friend
      */
     var $relation = 0;
 
+    /**
+     * 送信先メッセージID
+     * @var integer
+     */
+    var $to_message_id = 0;
+
     /**
      * 添付画像を送信
      * @var integer
@@ -151,43 +159,24 @@ class webapp extends WAP_friend
         if ($this->objmnp->getValue('status') != MESSAGE_SENT){
             return false;
         }
+        $objmnp = new RKT_manip($this->objdb, DB_PREFIX.'fri_message');
 
-        $this->send_mail();
+        $objmnp->setValue('modify',      date('Y-m-d H:i:s'));
+        $objmnp->setValue('regist_date', date('Y-m-d H:i:s'));
+        $objmnp->setValue('status',      MESSAGE_INBOX);
+        $objmnp->setValue('ref_account', $this->objmnp->getValue('ref_to'));
+        $objmnp->setValue('ref_to',      $this->objmnp->getValue('ref_to'));
+        $objmnp->setValue('ref_from',    $this->objmnp->getValue('ref_from'));
+        $objmnp->setValue('flag',        MESSAGE_FLAG_UNREAD);
+        $objmnp->setValue('subject',     $this->objmnp->getValue('subject'));
+        $objmnp->setValue('body',        $this->objmnp->getValue('body'));
 
-        $value = array(
-            'modify'=> $this->objmnp->getValue('modify'),
-            'regist_date'=> $this->objmnp->getValue('regist_date'),
-            'ref_account'=> $this->objmnp->getValue('ref_to'),
-            'ref_to'=> $this->objmnp->getValue('ref_to'),
-            'ref_from'=> $this->objmnp->getValue('ref_from'),
-            'subject'=> $this->objmnp->getValue('subject'),
-            'body'=> $this->objmnp->getValue('body'),
-        );
-
-        $sql =
-            'INSERT INTO '.
-                DB_PREFIX.'fri_message('.
-                    'modify,'.
-                    'regist_date,'.
-                    'status,'.
-                    'ref_account,'.
-                    'ref_to,'.
-                    'ref_from,'.
-                    'flag,'.
-                    'subject,'.
-                    'body'.
-                ') VALUES ('.
-                    "'".$value['modify']."',".
-                    "'".$value['regist_date']."',".
-                    MESSAGE_INBOX.','.
-                    $value['ref_account'].','.
-                    $value['ref_to'].','.
-                    $value['ref_from'].','.
-                    MESSAGE_FLAG_UNREAD.','.
-                    "'".$value['subject']."',".
-                    "'".$value['body']."'".
-                ')';
-        return $this->objdb->exec($sql);
+        $result = $objmnp->manip();
+        if ($result){
+            $this->send_mail();
+            $this->to_message_id = $objmnp->getCurID();
+        }
+        return $result;
     }
 
     /**
@@ -267,6 +256,7 @@ class webapp extends WAP_friend
         $objmnp->setValue('ref_table',     ACTION_FRI_MESSAGE);
         $objmnp->setValue('ref_relation',  $ref_relation);
         $objmnp->setValue('ref_account',   $this->account['id']);
+        $objmnp->setValue('ref_addition',  $this->to_message_id);
 
         return $objmnp->manip();
     }
