@@ -83,7 +83,8 @@ class webapp extends WAP_friend
 
         $this->set_topic();
         /* 閲覧権限があるか？ */
-        if (empty($this->visibility & $this->topic['visibility'])){
+        $visibility = $this->visibility & $this->topic['visibility'];
+        if (empty($visibility)){
             header('Location: '.HTTP_ACTION.'friend/forum/list/'.$this->sid.'/'.$this->ref_friend.'/');
             exit();
         }
