@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/08/19] 達プロフィールの最終ログイン日のエラーを修正
  -      [2007/02/13] 公開フラグをビットフラグに対応
  -      [2007/02/03] 市区町村条件指定エラーの修正
  -      [2006/07/10] 作成
@@ -169,6 +170,7 @@ class webapp extends WAP_friend
         $sql=
             'SELECT '.
                 'pro.id as id,'.
+                'act.last_login as last_login,'.
                 'pro.ref_account as ref_account,'.
                 'pro.modify as modify,'.
                 'pro.first_name as first_name,'.
