@@ -203,7 +203,9 @@ class webapp extends WAP_private
                 'cat.ref_diary = '.$this->ref_diary.' AND '.
                 'sel.ref_entry = '.$this->id.' '.
             'GROUP BY '.
-                'cat.id,sel.ref_category '.
+                'cat.id,'.
+                'cat.category,'.
+                'sel.ref_category '.
             'ORDER BY '.
                 'cat.sort';
         $stmt = $this->objdb->prepare($sql); 
