@@ -315,7 +315,12 @@ class webapp extends WAP_private
                 'ent.ref_account = '.$this->account['id'].' '.
                 $this->where.
             'GROUP BY '.
-                'ent.id '.
+                'ent.id,'.
+                'ent.modify,'.
+                'ent.regist_date,'.
+                'ent.visibility,'.
+                'ent.subject,'.
+                'ent.body '.
             'ORDER BY '.
                 'ent.regist_date DESC ';
         $objpgr->setSql($sql);
