@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/08/19] メールによる画像添付機能追加
  -      [2006/07/10] 作成
  - ======================================================================== */
 
@@ -56,6 +57,12 @@ class webapp extends WAP_private
      */
     var $objmnp = null;
 
+    /**
+     * 添付画像を送信
+     * @var integer
+     */
+    var $attach = 0;
+
     /**
      * 実行処理
      *
@@ -82,6 +89,8 @@ class webapp extends WAP_private
             exit();
         }
 
+        $this->set_attach();            // 画像添付フラグの設定
+
         // データ操作クラスの生成
         $this->objmnp = new RKT_manip($this->objdb, DB_PREFIX.'frm_comment');
         $result = $this->do_query();
@@ -91,14 +100,19 @@ class webapp extends WAP_private
             /* トピックの更新日を最新に */            
             $this->update_topic();
 
-            header('Location: '.HTTP_ACTION.'private/forum/browse/'.$this->sid.'/'.$this->ref_topic.'/');
+            $this->mail_action();
+            unset($_SESSION['attach']);
+
+            header('Location: '.HTTP_ACTION.'private/forum/comment/'.$this->sid.'/'.$this->ref_topic.'/complete/'.WAP_URI_SEPARATOR.'attach='.$this->attach);
             exit();
         } elseif ($result == RKT_MANIP_VALIDATED) {
+            $_SESSION['attach']     = $this->attach;
             header('Location: '.HTTP_ACTION.'private/forum/comment/'.$this->sid.'/'.$this->ref_topic.'/confirm/');
             exit();
         }
 
         $this->set_topic();
+        $this->Assign('attach', $this->attach);
     }
 
     /**
@@ -215,5 +229,56 @@ class webapp extends WAP_private
         $this->objdb->exec($sql);
         $this->objdb->commit();
     }
+
+    /******************************************************/
+    /**************    メールアクション     ***************/
+    /******************************************************/
+    /**
+     * 画像添付フラグの設定
+     *
+     * @access private
+     * @return array
+     */
+    function set_attach()
+    {
+        if (isSet($_POST['attach'])){
+            $this->attach = empty($_POST['attach'])?array():$_POST['attach'];
+            return ;
+        }
+        if (isSet($_SESSION['attach'])){
+            $this->attach = empty($_SESSION['attach'])?array():$_SESSION['attach'];
+            return ;
+        }
+        if (isSet($_GET['attach'])){
+            $this->attach = empty($_GET['attach'])?array():$_GET['attach'];
+            return ;
+        }
+        if (preg_match('/(manip|confirm|edit)/i',$_SERVER['REQUEST_URI'])){
+            return ;
+        }
+    }
+
+    /**
+     * メールアクション設定
+     *
+     * @access private
+     * @return integer  データ操作結果
+     */
+    function mail_action()
+    {
+        if (empty($this->attach)){
+            return false;
+        }
+        $ref_relation = $this->objmnp->getCurID();
+
+        $objmnp = new RKT_manip($this->objdb, DB_PREFIX.'act_mailaction');
+
+        $objmnp->setValue('modify',        date('Y-m-d H:i:s'));
+        $objmnp->setValue('ref_table',     ACTION_FRM_COMMENT);
+        $objmnp->setValue('ref_relation',  $ref_relation);
+        $objmnp->setValue('ref_account',   $this->account['id']);
+
+        return $objmnp->manip();
+    }
 } // webapp
 ?>
