@@ -39,18 +39,18 @@ require_once WEBAPP_LIB_DIR.'wap_private.php';
  */
 class webapp extends WAP_private
 {
-    /**
-     * データ操作オブジェクト
-     * @var object
-     */
-    var $objmnp = null;
-
     /**
      * スケジュールリスト
      * @var string
      */
     var $term = '';
 
+    /**
+     * 注目情報
+     * @var boolean
+     */
+    var $attention = false;
+
     /**
      * 実行処理
      *
@@ -88,6 +88,8 @@ class webapp extends WAP_private
         $this->set_review();
 
         $this->set_intro();
+
+        $this->Assign('attention', $this->attention);
     }
 
     /**
@@ -140,6 +142,9 @@ class webapp extends WAP_private
         $result = $stmt->fetch(PDO_FETCH_ASSOC);
         $stmt->closeCursor();
 
+        if (!empty($result['ct'])){
+            $this->attention = true;
+        }
         $this->Assign('friend_relation', $result['ct']);
     }
 
@@ -164,6 +169,9 @@ class webapp extends WAP_private
         $result = $stmt->fetch(PDO_FETCH_ASSOC);
         $stmt->closeCursor();
 
+        if (!empty($result['ct'])){
+            $this->attention = true;
+        }
         $this->Assign('admin_change', $result['ct']);
     }
 
@@ -191,6 +199,9 @@ class webapp extends WAP_private
         $result = $stmt->fetch(PDO_FETCH_ASSOC);
         $stmt->closeCursor();
 
+        if (!empty($result['ct'])){
+            $this->attention = true;
+        }
         $this->Assign('community_entry', $result['ct']);
     }
 
@@ -216,6 +227,9 @@ class webapp extends WAP_private
         $result = $stmt->fetch(PDO_FETCH_ASSOC);
         $stmt->closeCursor();
 
+        if (!empty($result['ct'])){
+            $this->attention = true;
+        }
         $this->Assign('new_message', $result['ct']);
     }
 
@@ -243,24 +257,10 @@ class webapp extends WAP_private
         $stmt->execute(); 
         $result = $stmt->fetchAll(PDO_FETCH_ASSOC);
 
+        if (!empty($result['ct'])){
+            $this->attention = true;
+        }
         $this->Assign('new_comment', count($result));
-
-        $sql=
-            'SELECT '.
-                'cmt.ref_entry ref_entry '.
-            'FROM '.
-                DB_PREFIX.'dia_diary dia,'.
-                DB_PREFIX.'dia_comment cmt '.
-            'WHERE '.
-                'dia.id = cmt.ref_diary AND '.
-                'cmt.flag = '.MESSAGE_FLAG_UNREAD.' AND '.
-                'dia.ref_account = '.$this->account['id'];
-        $stmt = $this->objdb->prepare($sql); 
-        $stmt->execute(); 
-        $result = $stmt->fetch(PDO_FETCH_ASSOC);
-        $stmt->closeCursor();
-
-        $this->Assign('new_comment_entry', $result['ref_entry']);
     }
 
     /**
@@ -395,12 +395,18 @@ class webapp extends WAP_private
      */
     function set_post()
     {
+        $orders = array(
+            'mysql'=>  'modify',
+            'sqlite'=> 'max(com.modify)',
+            'pgsql'=>  'modify',
+        );
+
         $sql=
             'SELECT '.
                 'ent.id as ref_entry,'.
                 'act.id as ref_friend,'.
                 'pro.nickname as nickname,'.
-                'com.modify as modify,'.
+                'max(com.modify) as modify,'.
                 'ent.post as ct,'.
                 'ent.subject as subject '.
             'FROM '.
@@ -419,11 +425,13 @@ class webapp extends WAP_private
                 'com.ref_account = '.$this->account['id'].' AND '.
                 'com.modify > '.$this->term.' '.
             'GROUP BY '.
+                'ent.id,'.
                 'act.id,'.
-                'dia.id,'.
-                'ent.id '.
+                'pro.nickname,'.
+                'ent.post,'.
+                'ent.subject '.
             'ORDER BY '.
-                'com.modify DESC '.
+                $orders[WAP_DB_DRIVER].' DESC '.
             'LIMIT 5';
         $stmt = $this->objdb->prepare($sql); 
         $stmt->execute(); 
@@ -440,19 +448,23 @@ class webapp extends WAP_private
      */
     function set_topic()
     {
+        $orders = array(
+            'mysql'=>  'modify',
+            'sqlite'=> 'max(tpc.modify)',
+            'pgsql'=>  'modify',
+        );
+
         $sql=
             'SELECT '.
                 'com.id as ref_community,'.
                 'com.community as community,'.
                 'tpc.id as ref_topic,'.
                 'tpc.topic as topic,'.
-                'tpc.modify as modify,'.
+                'max(tpc.modify) as modify,'.
                 'tpc.status as status,'.
                 'tpc.post as ct '.
             'FROM '.
-                DB_PREFIX.'com_topic tpc '.
-                    'LEFT JOIN '.DB_PREFIX.'com_comment cmt '.
-                    'ON tpc.id = cmt.ref_topic,'.
+                DB_PREFIX.'com_topic tpc,'.
                 DB_PREFIX.'act_account act,'.
                 DB_PREFIX.'com_community com,'.
                 DB_PREFIX.'com_names nam '.
@@ -468,10 +480,13 @@ class webapp extends WAP_private
                 'nam.status != '.STATUS_COMMUNITY_REQUEST.' '.
             'GROUP BY '.
                 'com.id,'.
+                'com.community,'.
                 'tpc.id,'.
-                'nam.id '.
+                'tpc.topic,'.
+                'tpc.status,'.
+                'tpc.post '.
             'ORDER BY '.
-                'tpc.modify DESC '.
+                $orders[WAP_DB_DRIVER].' DESC '.
             'LIMIT 5';
         $stmt = $this->objdb->prepare($sql); 
         $stmt->execute(); 
@@ -609,12 +624,18 @@ class webapp extends WAP_private
      */
     function set_comment()
     {
+        $orders = array(
+            'mysql'=>  'modify',
+            'sqlite'=> 'max(com.modify)',
+            'pgsql'=>  'modify',
+        );
+
         $sql=
             'SELECT '.
                 'ent.id as ref_entry,'.
                 'act.id as ref_friend,'.
                 'pro.nickname as nickname,'.
-                'com.modify as modify,'.
+                'max(com.modify) as modify,'.
                 'ent.post as ct,'.
                 'ent.subject as subject '.
             'FROM '.
@@ -633,10 +654,13 @@ class webapp extends WAP_private
                 'dia.ref_account = '.$this->account['id'].' '.
             'GROUP BY '.
                 'act.id,'.
+                'pro.nickname,'.
                 'dia.id,'.
-                'ent.id '.
+                'ent.id,'.
+                'ent.post,'.
+                'ent.subject '.
             'ORDER BY '.
-                'com.modify DESC '.
+                $orders[WAP_DB_DRIVER].' DESC '.
             'LIMIT 5';
         $stmt = $this->objdb->prepare($sql); 
         $stmt->execute(); 
