@@ -80,11 +80,11 @@ class webapp extends WAP_public
         $this->setTemplateFile('public/registry/registry.tpl');
 
         /* PathInfo引数の設定 */
-        $this->setPathInfo('ref_invite');
+        $this->setPathInfo('ref_invite', -1);
         $this->Assign('ref_invite', $this->ref_invite);
-        $this->setPathInfo('seed',1,'string');
+        $this->setPathInfo('seed', 0, 'string');
         $this->Assign('seed', $this->seed);
-        $this->setPathInfo('key',2,'string');
+        $this->setPathInfo('key', 1, 'string');
         $this->Assign('key', $this->key);
 
     	if ($this->check_keyword()){
