@@ -89,19 +89,41 @@ class webapp extends WAP_public
         $this->objmnp = new RKT_manip($this->objdb, DB_PREFIX.'act_account');
         $result = $this->do_query();
         if ($result == RKT_MANIP_COMPLETE){
-            $this->insert_profile();
+            $this->query_profile();
             $this->update_invite();
             $this->send_mail();
             /* 入力セッションの破棄 */
             unset($_SESSION[DB_PREFIX.'act_account']);
-
-            $this->request_sns();
-            $this->request_entry();
         } else {
             $this->error = true;
         }
     }
 
+    /**
+     * アカウントIDの取得
+     *
+     * @access private
+     * @return integer
+     */
+    function get_curid()
+    {
+        $email_hash = $_SESSION[DB_PREFIX.'act_account']['email'];
+        $email_hash = sql_query::hash($email_hash);
+        $sql=
+            'SELECT '.
+                'id '.
+            'FROM '.
+                DB_PREFIX.'act_account '.
+            'WHERE '.
+                'avail = '.AVAIL_PENDING.' AND '.
+                "email_hash = '".$email_hash."'";
+        $stmt = $this->objdb->prepare($sql); 
+        $stmt->execute(); 
+        $result = $stmt->fetch(PDO_FETCH_ASSOC);
+
+        return empty($result['id'])?null:$result['id'];
+    }
+
     /**
      * データ操作設定・実行
      *
@@ -112,6 +134,8 @@ class webapp extends WAP_public
     {
         $this->objmnp->setRequestType("_SESSION['".DB_PREFIX.'act_account'."']");
 
+        $this->objmnp->setCurID($this->get_curid());
+
         /* 直接入力 */
         $this->objmnp->setValue('modify', date('Y-m-d H:i:s'));
         $this->objmnp->setValue('avail', AVAIL_PENDING);
@@ -146,50 +170,55 @@ class webapp extends WAP_public
      * @access private
      * @return boolean  真偽値
      */
-    function insert_profile()
+    function query_profile()
     {
+        $ref_account = $this->objmnp->getCurID();
+        $sql=
+            'SELECT '.
+                'id '.
+                'ref_friend '.
+            'FROM '.
+                DB_PREFIX.'act_profile '.
+            'WHERE '.
+                'ref_account = '.$ref_account;
+        $stmt = $this->objdb->prepare($sql); 
+        $stmt->execute(); 
+        $result = $stmt->fetch(PDO_FETCH_ASSOC);
+        $stmt->closeCursor();
+
+        $objmnp = new RKT_manip($this->objdb, DB_PREFIX.'act_profile');
+        if (!empty($result['id'])){
+            $objmnp->setCurID($result['id']);
+        }
+
         $first_name  = $_SESSION[DB_PREFIX.'act_account']['first_name'];
         $second_name = $_SESSION[DB_PREFIX.'act_account']['second_name'];
         $nickname    = $_SESSION[DB_PREFIX.'act_account']['nickname'];
-
         $first_name  = sql_query::encrypt($first_name);
         $second_name = sql_query::encrypt($second_name);
 
-        $values = array(
-            'ref_account'=> $this->objmnp->getCurID(),
-            'modify'=> $this->objdb->quote(date('Y-m-d H:i:s')),
-            'first_name'=> $this->objdb->quote($first_name),
-            'second_name'=> $this->objdb->quote($second_name),
-            'name_flag'=> VISIBILITY_HIDDEN,
-            'nickname'=> $this->objdb->quote($nickname),
-            'visibility'=> VISIBILITY_PUBLIC,                   // ネット上に公開 2007/01/03変更
-            'ref_prefecture'=> '48',                            // その他
-            'local'=> 'NULL',
-            'prefecture_flag'=> VISIBILITY_HIDDEN,
-            'ref_sex'=> '3',                                    // 未記入
-            'sex_flag'=> VISIBILITY_HIDDEN,
-            'ref_blood'=> '5',                                  // 不明
-            'blood_flag'=> VISIBILITY_HIDDEN,
-            'birthday'=> $this->objdb->quote(date('Y-m-d H:i:s')),
-            'birthday_flag'=> VISIBILITY_HIDDEN,
-            'age_flag'=> VISIBILITY_HIDDEN,
-            'ref_married'=> '1',                                // 無回答
-            'married_flag'=> VISIBILITY_HIDDEN,
-            'ref_hometown'=> 'NULL',
-            'homelocal'=> 'NULL',
-            'hometown_flag'=> VISIBILITY_HIDDEN,
-            'publicity'=> 'NULL',
-        );
+        $objmnp->setValue('ref_account',    $ref_account);
+        $objmnp->setValue('modify',         date('Y-m-d H:i:s'));
+        $objmnp->setValue('first_name',     $first_name);
+        $objmnp->setValue('second_name',    $second_name);
+        $objmnp->setValue('name_flag',      VISIBILITY_HIDDEN);
+        $objmnp->setValue('nickname',       $nickname);
+        $objmnp->setValue('visibility',     VISIBILITY_PROTECTED);
+        $objmnp->setValue('ref_prefecture', '49');                  // その他
+        $objmnp->setValue('ref_local',      '0');                   // 
+        $objmnp->setValue('prefecture_flag',VISIBILITY_HIDDEN);
+        $objmnp->setValue('ref_sex',        '3');                   // 未記入
+        $objmnp->setValue('sex_flag',       VISIBILITY_HIDDEN);
+        $objmnp->setValue('ref_blood',      '5');                   // 不明
+        $objmnp->setValue('blood_flag',     VISIBILITY_HIDDEN);
+        $objmnp->setValue('birthday',       date('Y-m-d H:i:s'));
+        $objmnp->setValue('birthday_flag',  VISIBILITY_HIDDEN);
+        $objmnp->setValue('age_flag',       VISIBILITY_HIDDEN);
+        $objmnp->setValue('ref_married',    '1');                   // 無回答
+        $objmnp->setValue('married_flag',   VISIBILITY_HIDDEN);
+        $objmnp->setValue('hometown_flag',  VISIBILITY_HIDDEN);
 
-        $keys = array_keys($values);
-        $column = implode(',',$keys);
-        $value = implode(',',$values);
-
-        $sql =
-            'INSERT INTO '.
-                DB_PREFIX.'act_profile('.$column.')'.
-                ' VALUES ('.$value.')';
-        return $this->objdb->exec($sql);
+        return $objmnp->manip();
     }
 
     /**
