@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/08/13] アクションメール設定を追加
  -      [2007/07/23] CHUNK文字数を追加
  -      [2007/07/07] SMTPの設定を追加
  -      [2007/07/05] Smarty設定ディレクトリパスの変更
@@ -114,6 +115,19 @@ define('POP3_PASSWORD', 'passwd');                                  // POP3パ
 /* メールボックス設定 */
 define('MAIL_BOX_DIR', '');                                         // メールボックスのディレクトリ
 
+/* ---------------------------------------- */
+/* アクションメール設定 */
+define('ACTION_MAIL', 'post@example.com');                          // POP3ホスト
+
+define('ACTION_ACT_PHOTO',     1);                                  // 会員写真
+define('ACTION_DIA_ENTRY',     2);                                  // 日記記事
+define('ACTION_FRI_MESSAGE',   3);                                  // メッセージ
+define('ACTION_FRM_TOPIC',     4);                                  // フォーラムトピック
+define('ACTION_FRM_COMMENT',   5);                                  // フォーラムコメント
+define('ACTION_COM_COMMUNITY', 6);                                  // コミュニティ
+define('ACTION_COM_TOPIC',     7);                                  // コミュニティトピック
+define('ACTION_COM_COMMENT',   8);                                  // コミュニティコメント
+
 /* ---------------------------------------- */
 /* デバッグモード */
 define('DEBUG_ENV', FALSE);                                         // デバッグモード
