@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/08/30] カテゴリ数一覧取得にsel.ref_diaryを追加
  -      [2007/02/13] 公開レベルをビットフラグに対応
  -      [2006/07/25] 作成
  - ======================================================================== */
@@ -354,9 +355,11 @@ class dia_menu
                 'ent.id = sel.ref_entry AND '.
                 'cat.id = sel.ref_category AND '.
                 'cat.ref_diary = '.$this->diary['id'].' AND '.
+                'sel.ref_diary = '.$this->diary['id'].' AND '.
                 sql_query::bitFlag('ent.visibility & '.$this->visibility).' '.
             'GROUP BY '.
-                'cat.id '.
+                'cat.id,'.
+                'cat.category '.
             'ORDER BY '.
                 'cat.sort';
         $stmt = $this->objdb->prepare($sql); 
