@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/08/30] アンケートの回答の更新処理にrkt_manipクラスを使用
  -      [2007/02/02] リスト選択時のデフォルト値エラー修正
  -      [2006/07/31] 作成
  - ======================================================================== */
@@ -471,63 +472,47 @@ class act_enquete extends RKT_validate
             if ($row['form_type'] == FORM_TYPE_CHECKBOX){
                 $this->do_query_select($value);
             } else {
-                $result = $this->update_content($value);
-                if (!$result){
-                    $result = $this->insert_content($value);
-                }
-            } // if ($row['form_type'] == FORM_TYPE_CHECKBOX)
-        }
+                $result = $this->manip_content($value);
+            }
+        } // foreach ($this->enquetes as $row)
 
         return true;
     }
 
     /**
-     * アンケートの回答を新規登録
+     * アンケートの回答を更新
      *
      * @access private
-     * @param integer $ref_item   選択肢ID
+     * @param array $value
      * @return boolean  真偽値
      */
-    function update_content($value)
+    function manip_content($value)
     {
-        $sql =
-            'UPDATE '.
+        $sql=
+            'SELECT '.
+                'id '.
+            'FROM '.
                 DB_PREFIX.'act_content '.
-            'SET '.
-                'ref_item='.$value['ref_item'].','.
-                'visibility='.$value['visibility'].','.
-                'content='."'".$value['content']."' ".
             'WHERE '.
                 'ref_enquete = '.$value['ref_enquete'].' AND '.
                 'ref_account = '.$value['ref_account'];
-        return $this->objdb->exec($sql);
-    }
+        $stmt = $this->objdb->prepare($sql); 
+        $stmt->execute(); 
+        $result = $stmt->fetch(PDO_FETCH_ASSOC);
+        $stmt->closeCursor();
 
-    /**
-     * アンケートの回答を新規登録
-     *
-     * @access private
-     * @param integer $ref_item   選択肢ID
-     * @return boolean  真偽値
-     */
-    function insert_content($value)
-    {
-        $sql =
-            'INSERT INTO '.
-                DB_PREFIX.'act_content('.
-                    'ref_enquete,'.
-                    'ref_item,'.
-                    'ref_account,'.
-                    'visibility,'.
-                    'content'.
-                ') VALUES ('.
-                    $value['ref_enquete'].','.
-                    $value['ref_item'].','.
-                    $value['ref_account'].','.
-                    $value['visibility'].','.
-                    "'".$value['content']."'".
-                ')';
-        return $this->objdb->exec($sql);
+        /* テーブルの更新処理 */
+        $objmnp = new RKT_manip($this->objdb, DB_PREFIX.'act_content');
+        if (!empty($result['id'])){
+            $objmnp->setCurID($result['id']);
+        }
+        $objmnp->setValue('ref_enquete',    $value['ref_enquete']);
+        $objmnp->setValue('ref_item',       $value['ref_item']);
+        $objmnp->setValue('ref_account',    $value['ref_account']); 
+        $objmnp->setValue('visibility',     $value['visibility']);
+        $objmnp->setValue('content',        $value['content']);
+
+        return $objmnp->manip();
     }
 
     /**
