@@ -21,11 +21,13 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/08/30] 画像の更新処理にrkt_manipクラスを使用
  -      [2007/06/20] XSS対応
  -      [2006/07/25] 作成
  - ======================================================================== */
 
 require_once LIB_DIR.'rkt_db.php';
+require_once LIB_DIR.'rkt_manip.php';
 require_once LIB_DIR.'rkt_upload.php';
 
 /**
@@ -186,62 +188,30 @@ class dia_pictures
         $large = $this->objfile->saveResize($large_path,PHOTO_MAX_SIZE,PHOTO_MAX_SIZE);
         $small = $this->objfile->saveResize($small_path,PHOTO_SMALL_SIZE,PHOTO_SMALL_SIZE);
 
-        $values = array(
-            'title'=> $filename,
-            'filename'=> $large_path,
-            'width'=> $large['width'],
-            'height'=> $large['height'],
-            'thumbnail'=> $small_path,
-            't_width'=> $small['width'],
-            't_height'=> $small['height'],
-        );
-
+        /* テーブルの更新処理 */
+        $objmnp = new RKT_manip($this->objdb, DB_PREFIX.'dia_picture');
         if (empty($id)){
-            $this->insert($values);
+            $objmnp->setValue('ref_account',    $this->ref_account);
         } else {
-            $this->update($id,$values);
+            $objmnp->setCurID($id);
+            $this->file_unlink($id);
         }
-        return true;
-    }
 
-    /**
-     * 添付画像を新規登録
-     *
-     * @access private
-     * @param array $values
-     * @return boolean  真偽値
-     */
-    function insert($values)
-    {
-        $sql =
-            'INSERT INTO '.
-                DB_PREFIX.'dia_picture('.
-                    'modify,'.
-                    'ref_account,'.
-                    'title,'.
-                    'filename,'.
-                    'width,'.
-                    'height,'.
-                    'thumbnail,'.
-                    't_width,'.
-                    't_height'.
-                ') VALUES ('.
-                    "'".date('Y-m-d H:i:s')."',".
-                    $this->ref_account.','.
-                    "'".$values['title']."',".
-                    "'".$values['filename']."',".
-                    $values['width'].','.
-                    $values['height'].','.
-                    "'".$values['thumbnail']."',".
-                    $values['t_width'].','.
-                    $values['t_height'].
-                ')';
-        $result = $this->objdb->exec($sql);
-        if ($result){
-            $id = $this->objdb->lastInsertId();
-            $this->ids[$id] = $id;
-        }
-        return $result;
+        $objmnp->setValue('modify',         date('Y-m-d H:i:s'));
+        $objmnp->setValue('title',          $filename);
+        $objmnp->setValue('filename',       $large_path);
+        $objmnp->setValue('width',          $large['width']);
+        $objmnp->setValue('height',         $large['height']);
+        $objmnp->setValue('thumbnail',      $small_path);
+        $objmnp->setValue('t_width',        $small['width']);
+        $objmnp->setValue('t_height',       $small['height']);
+
+        $objmnp->manip();
+
+        $id = $objmnp->getCurID();
+        $this->ids[$id] = $id;
+
+        return true;
     }
 
     /**
@@ -249,10 +219,9 @@ class dia_pictures
      *
      * @access private
      * @param integer $id
-     * @param array $values
      * @return boolean  真偽値
      */
-    function update($id,$values)
+    function file_unlink($id)
     {
         $sql=
             'SELECT '.
@@ -271,26 +240,7 @@ class dia_pictures
             $this->objfile->unlink($result['filename']);
             $this->objfile->unlink($result['thumbnail']);
         }
-
-        $sql =
-            'UPDATE '.
-                DB_PREFIX.'dia_picture '.
-            'SET '.
-                "modify='".date('Y-m-d H:i:s')."',".
-                "title='".$values['title']."',".
-                "filename='".$values['filename']."',".
-                'width='.$values['width'].','.
-                'height='.$values['height'].','.
-                "thumbnail='".$values['thumbnail']."',".
-                't_width='.$values['t_width'].','.
-                't_height='.$values['t_height'].' '.
-            'WHERE '.
-                'id = '.$id;
-        $result = $this->objdb->exec($sql);
-        if ($result){
-            $this->ids[$id] = $id;
-        }
-        return $result;
+        return true;
     }
 
     /**
