@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/08/30] 名簿の更新処理にrkt_manipクラスを使用
  -      [2007/06/17] コミュニティ：トピック、イベント、記事、アンケート権限追加
  -      [2007/01/30] カテゴリ選択更新時エラーを修正
  -      [2006/08/27] コミュニティカテゴリを複数選択対応
@@ -203,32 +204,15 @@ class webapp extends WAP_community
             return ;
         }
         
-        $this->insert_names();
-        $this->make_dir();
-    }
+        /* 名簿を新規登録 */
+        $objmnp = new RKT_manip($this->objdb, DB_PREFIX.'com_names');
+        $objmnp->setValue('modify',         date('Y-m-d H:i:s'));
+        $objmnp->setValue('ref_community',  $this->ref_community);
+        $objmnp->setValue('ref_account',    $this->account['id']);
+        $objmnp->setValue('status',         STATUS_COMMUNITY_ADMIN);
+        $objmnp->manip();
 
-    /**
-     * 名簿を新規登録
-     *
-     * @access private
-     * @return boolean  真偽値
-     */
-    function insert_names()
-    {
-        $sql =
-            'INSERT INTO '.
-                DB_PREFIX.'com_names('.
-                    'modify,'.
-                    'ref_community,'.
-                    'ref_account,'.
-                    'status'.
-                ') VALUES ('.
-                    "'".date('Y-m-d H:i:s')."',".
-                    $this->ref_community.','.
-                    $this->account['id'].','.
-                    STATUS_COMMUNITY_ADMIN.
-                ')';
-        return $this->objdb->exec($sql);
+        $this->make_dir();
     }
 
     /**
