@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/08/30] メッセージの更新処理にrkt_manipクラスを使用
  -      [2006/08/28] 紹介者の取得部分を修正
  -      [2006/08/27] 基礎情報を親クラスから引っ張るように修正
  -      [2006/07/10] 作成
@@ -227,56 +228,23 @@ class webapp extends WAP_community
             '[コミュニティのUR]:'."\r\n".
             HTTP_ACTION.'community/show/community/'.$this->ref_community.'/'."\r\n";
 
+        /* テーブルの更新処理 */
+        $objmnp = new RKT_manip($this->objdb, DB_PREFIX.'fri_message');
 
-        $value = array(
-            'modify'=> date('Y-m-d H:i:s'),
-            'regist_date'=> date('Y-m-d H:i:s'),
-            'ref_account'=> 0,
-            'ref_to'=> 0,
-            'ref_from'=> $this->account['id'],
-            'subject'=> 'コミュニティおすすめメッセージ',
-            'body'=> $body,
-        );
+        $objmnp->setValue('modify',      date('Y-m-d H:i:s'));
+        $objmnp->setValue('regist_date', date('Y-m-d H:i:s'));
+        $objmnp->setValue('status',      MESSAGE_INBOX);
+        $objmnp->setValue('ref_from',    $this->account['id']);
+        $objmnp->setValue('flag',        MESSAGE_FLAG_UNREAD);
+        $objmnp->setValue('subject',     'コミュニティおすすめメッセージ');
+        $objmnp->setValue('body',        $body);
 
         foreach ($this->ref_friends as $id){
-            $value['ref_account'] = $id;
-            $value['ref_to'] = $id;
-            $this->insert_message($value);
+            $objmnp->setCurID(0);       // 常に挿入処理
+            $objmnp->setValue('ref_account', $id);
+            $objmnp->setValue('ref_to',      $id);
+            $objmnp->manip();
         }
     }
-
-    /**
-     * メッセージの送信
-     *
-     * @access private
-     * @return integer  データ操作結果
-     */
-    function insert_message($value)
-    {
-        $sql =
-            'INSERT INTO '.
-                DB_PREFIX.'fri_message('.
-                    'modify,'.
-                    'regist_date,'.
-                    'status,'.
-                    'ref_account,'.
-                    'ref_to,'.
-                    'ref_from,'.
-                    'flag,'.
-                    'subject,'.
-                    'body'.
-                ') VALUES ('.
-                    "'".$value['modify']."',".
-                    "'".$value['regist_date']."',".
-                    MESSAGE_INBOX.','.
-                    $value['ref_account'].','.
-                    $value['ref_to'].','.
-                    $value['ref_from'].','.
-                    MESSAGE_FLAG_UNREAD.','.
-                    "'".$value['subject']."',".
-                    "'".$value['body']."'".
-                ')';
-        return $this->objdb->exec($sql);
-    }
 } // webapp
 ?>
