@@ -418,20 +418,23 @@ class webapp extends WAP_community
     {
         $list = array();
         foreach ($this->com_option as $value){
-            $value['item'] = $this->objdb->quote($value['item']);
+            if (!empty($value['item'])){
+                $value['item'] = $this->objdb->quote($value['item']);
 
-            if (empty($value['id'])){
-                $value['id'] = $this->insert_option($value);
-            } else {
-                $this->update_option($value);
+                if (empty($value['id'])){
+                    $value['id'] = $this->insert_option($value);
+                } else {
+                    $this->update_option($value);
+                }
+                $list[$value['id']] = $value['id'];
             }
-            $list[$value['id']] = $value['id'];
-        }
+        } // foreach ($this->com_option as $value)
 
         /* 削除用の処理 */
         $sql=
             'SELECT '.
-                'id '.
+                'id,'.
+                'item '.
             'FROM '.
                 DB_PREFIX.'com_option '.
             'WHERE '.
@@ -448,6 +451,11 @@ class webapp extends WAP_community
             if (empty($list[$value['id']])){
                 $this->delete_option($value['id']);
             }
+
+            if (empty($value['item'])){
+                $this->delete_option($value['id']);
+            }
+
         } // foreach ($result as $value)
 
         return true;
