@@ -262,7 +262,10 @@ class webapp extends WAP_community
                 'tpc.status = '.STATUS_TOPIC_BULLETIN.' AND '.
                 'tpc.ref_community = '.$this->ref_community.' '.
             'GROUP BY '.
-                'tpc.id '.
+                'tpc.id,'.
+                'tpc.modify,'.
+                'tpc.topic,'.
+                'tpc.post '.
             'ORDER BY '.
                 'tpc.modify DESC '.
             'LIMIT 5';
@@ -298,7 +301,10 @@ class webapp extends WAP_community
                 'tpc.status = '.STATUS_TOPIC_EVENT.' AND '.
                 'tpc.ref_community = '.$this->ref_community.' '.
             'GROUP BY '.
-                'tpc.id '.
+                'tpc.id,'.
+                'tpc.modify,'.
+                'tpc.topic,'.
+                'tpc.post '.
             'ORDER BY '.
                 'tpc.modify DESC '.
             'LIMIT 5';
@@ -334,7 +340,10 @@ class webapp extends WAP_community
                 'tpc.status = '.STATUS_TOPIC_ITEM.' AND '.
                 'tpc.ref_community = '.$this->ref_community.' '.
             'GROUP BY '.
-                'tpc.id '.
+                'tpc.id,'.
+                'tpc.modify,'.
+                'tpc.topic,'.
+                'tpc.post '.
             'ORDER BY '.
                 'tpc.modify DESC '.
             'LIMIT 5';
@@ -370,7 +379,10 @@ class webapp extends WAP_community
                 'tpc.status = '.STATUS_TOPIC_ENQUETE.' AND '.
                 'tpc.ref_community = '.$this->ref_community.' '.
             'GROUP BY '.
-                'tpc.id '.
+                'tpc.id,'.
+                'tpc.modify,'.
+                'tpc.topic,'.
+                'tpc.post '.
             'ORDER BY '.
                 'tpc.modify DESC '.
             'LIMIT 5';
