@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/07/05] コメント数取得を分離
  -      [2007/02/13] 公開レベルをビットフラグに対応
  -      [2006/07/28] 作成
  - ======================================================================== */
@@ -199,13 +200,10 @@ class webapp extends WAP_private
                 'ent.visibility as visibility,'.
                 'ent.subject as subject,'.
                 'ent.body as body,'.
-                'count(cmt.id) as comments,'.
                 'pro.nickname as nickname,'.
                 'sex.sex as sex '.
             'FROM '.
-                DB_PREFIX.'dia_entry ent '.
-                'LEFT JOIN '.DB_PREFIX.'dia_comment cmt '.
-                    'ON ent.id = cmt.ref_entry,'.
+                DB_PREFIX.'dia_entry ent,'.
                 DB_PREFIX.'act_sex sex,'.
                 DB_PREFIX.'act_account act,'.
                 DB_PREFIX.'act_profile pro '.
@@ -215,10 +213,7 @@ class webapp extends WAP_private
                 'sex.id = pro.ref_sex AND '.
                 'act.avail = '.AVAIL_ENABLE.' AND '.
                 sql_query::bitFlag('ent.visibility & '.VISIBILITY_OPEN).' '.
-                $this->where.
-            'GROUP BY '.
-                'ent.id,'.
-                'act.id '.
+                $this->where.' '.
             $this->order;
         $objpgr->setSql($sql);
 
@@ -234,6 +229,7 @@ class webapp extends WAP_private
         }
         foreach ($result as $key=>$value){
             $result[$key]['picture'] = $this->get_picture($value['id']);
+            $result[$key]['comments'] = $this->get_comments($value['id']);
         }
 
         $this->Assign('topics', $result);
@@ -266,5 +262,29 @@ class webapp extends WAP_private
         
         return $result;
     }
+
+    /**
+     * コメント数の取得
+     *
+     * @access private
+     * @param integer $ref_entry
+     * @return integer
+     */
+    function get_comments($ref_entry)
+    {
+        $sql=
+            'SELECT '.
+                'count(cmt.id) as comments '.
+            'FROM '.
+                DB_PREFIX.'dia_comment '.
+            'WHERE '.
+                'ref_entry = '.$ref_entry;
+        $stmt = $this->objdb->prepare($sql); 
+        $stmt->execute(); 
+        $result = $stmt->fetch(PDO_FETCH_ASSOC);
+        $stmt->closeCursor();
+        
+        return empty($result['comments'])?0:$result['comments'];
+    }
 } // webapp
 ?>
