@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/08/30] メッセージの更新処理にrkt_manipクラスを使用
  -      [2007/03/08] 下書き時にも自動通知メールが送信されるエラーを修正
  -      [2007/01/31] 画像添付の追加
  -      [2006/08/28] メール送信部位、テンプレート変数変更
@@ -112,7 +113,7 @@ class webapp extends WAP_friend
             /* 添付画像処理 */
             $objpic->doDelete(true);
             $objpic->setFix($id);
-            $objpic->setCopy($this->to_message_id,$this->ref_friend);
+            $objpic->setCopy($this->to_message_id, $this->ref_friend);
             $objpic->unSetPicture();
 
             header('Location: '.HTTP_ACTION.'private/message/list/'.$this->objmnp->getValue('status').'/');
@@ -172,43 +173,22 @@ class webapp extends WAP_friend
         if ($this->objmnp->getValue('status') != MESSAGE_SENT){
             return false;
         }
-        $value = array(
-            'modify'=> $this->objmnp->getValue('modify'),
-            'regist_date'=> $this->objmnp->getValue('regist_date'),
-            'ref_account'=> $this->objmnp->getValue('ref_to'),
-            'ref_to'=> $this->objmnp->getValue('ref_to'),
-            'ref_from'=> $this->objmnp->getValue('ref_from'),
-            'subject'=> $this->objmnp->getValue('subject'),
-            'body'=> $this->objmnp->getValue('body'),
-        );
+        $objmnp = new RKT_manip($this->objdb, DB_PREFIX.'fri_message');
 
-        $sql =
-            'INSERT INTO '.
-                DB_PREFIX.'fri_message('.
-                    'modify,'.
-                    'regist_date,'.
-                    'status,'.
-                    'ref_account,'.
-                    'ref_to,'.
-                    'ref_from,'.
-                    'flag,'.
-                    'subject,'.
-                    'body'.
-                ') VALUES ('.
-                    "'".$value['modify']."',".
-                    "'".$value['regist_date']."',".
-                    MESSAGE_INBOX.','.
-                    $value['ref_account'].','.
-                    $value['ref_to'].','.
-                    $value['ref_from'].','.
-                    MESSAGE_FLAG_UNREAD.','.
-                    "'".$value['subject']."',".
-                    "'".$value['body']."'".
-                ')';
-        $result = $this->objdb->exec($sql);
+        $objmnp->setValue('modify',      date('Y-m-d H:i:s'));
+        $objmnp->setValue('regist_date', date('Y-m-d H:i:s'));
+        $objmnp->setValue('status',      MESSAGE_INBOX);
+        $objmnp->setValue('ref_account', $this->objmnp->getValue('ref_to'));
+        $objmnp->setValue('ref_to',      $this->objmnp->getValue('ref_to'));
+        $objmnp->setValue('ref_from',    $this->objmnp->getValue('ref_from'));
+        $objmnp->setValue('flag',        MESSAGE_FLAG_UNREAD);
+        $objmnp->setValue('subject',     $this->objmnp->getValue('subject'));
+        $objmnp->setValue('body',        $this->objmnp->getValue('body'));
+
+        $result = $objmnp->manip();
         if ($result){
             $this->send_mail();
-            $this->to_message_id = $this->objdb->lastInsertId();
+            $this->to_message_id = $objmnp->getCurID();
         }
         return $result;
     }
