@@ -111,7 +111,8 @@ class webapp extends WAP_private
             'WHERE '.
                 'prf.ref_area = '.$ref_area.' '.
             'GROUP BY '.
-                'prf.id '.
+                'prf.id,'.
+                'prf.prefecture '.
             'ORDER BY '.
                 'prf.id';
         $stmt = $this->objdb->prepare($sql); 
@@ -156,7 +157,8 @@ class webapp extends WAP_private
                     'LEFT JOIN '.DB_PREFIX.'act_profile pro '.
                         'ON sex.id = pro.ref_sex '.
             'GROUP BY '.
-                'sex.id '.
+                'sex.id,'.
+                'sex.sex '.
             'ORDER BY '.
                 'sex.id';
         $stmt = $this->objdb->prepare($sql); 
@@ -184,7 +186,8 @@ class webapp extends WAP_private
                     'LEFT JOIN '.DB_PREFIX.'act_profile pro '.
                         'ON bld.id = pro.ref_blood '.
             'GROUP BY '.
-                'bld.id '.
+                'bld.id,'.
+                'bld.blood '.
             'ORDER BY '.
                 'bld.id';
         $stmt = $this->objdb->prepare($sql); 
@@ -212,7 +215,8 @@ class webapp extends WAP_private
                     'LEFT JOIN '.DB_PREFIX.'act_profile pro '.
                         'ON mri.id = pro.ref_married '.
             'GROUP BY '.
-                'mri.id '.
+                'mri.id,'.
+                'mri.married '.
             'ORDER BY '.
                 'mri.id';
         $stmt = $this->objdb->prepare($sql); 
@@ -303,7 +307,8 @@ class webapp extends WAP_private
             'WHERE '.
                 'itm.ref_enquete = '.$ref_enquete.' '.
             'GROUP BY '.
-                'itm.id';
+                'itm.id,'.
+                'itm.item';
         $stmt = $this->objdb->prepare($sql); 
         $stmt->execute(); 
         $result = $stmt->fetchAll(PDO_FETCH_ASSOC);
@@ -353,7 +358,8 @@ class webapp extends WAP_private
             'WHERE '.
                 'itm.ref_enquete = '.$ref_enquete.' '.
             'GROUP BY '.
-                'itm.id';
+                'itm.id,'.
+                'itm.item';
         $stmt = $this->objdb->prepare($sql); 
         $stmt->execute(); 
         $result = $stmt->fetchAll(PDO_FETCH_ASSOC);
