@@ -565,7 +565,8 @@ class webapp extends WAP_private
             'WHERE '.
                 'cat.ref_account = '.$this->account['id'].' '.
             'GROUP BY '.
-                'cat.id '.
+                'cat.id,'.
+                'cat.category '.
             'ORDER BY '.
                 'cat.sort';
         $stmt = $this->objdb->prepare($sql); 
