@@ -124,9 +124,16 @@ class webapp extends WAP_private
                 'dia.ref_account != '.$this->account['id'].' AND '.
                 'com.ref_account = '.$this->account['id'].' '.
             'GROUP BY '.
+                'ent.id,'.
                 'act.id,'.
-                'dia.id,'.
-                'ent.id '.
+                'pro.nickname,'.
+                'com.modify,'.
+                'ent.post,'.
+                'ent.subject,'.
+                'ent.body,'.
+                'pht.thumbnail,'.
+                'pht.t_width,'.
+                'pht.t_height '.
             'ORDER BY '.
                 'com.modify DESC ';
         $objpgr->setSql($sql);
@@ -186,8 +193,16 @@ class webapp extends WAP_private
                 'nam.status != '.STATUS_COMMUNITY_REQUEST.' '.
             'GROUP BY '.
                 'com.id,'.
+                'com.community,'.
                 'tpc.id,'.
-                'nam.id '.
+                'tpc.status,'.
+                'tpc.topic,'.
+                'tpc.comment,'.
+                'com.modify,'.
+                'tpc.post,'.
+                'pic.thumbnail,'.
+                'pic.t_width,'.
+                'pic.t_height '.
             'ORDER BY '.
                 'cmt.modify DESC ';
         $objpgr->setSql($sql);
