@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/08/30] メッセージの更新処理にrkt_manipクラスを使用
  -      [2007/03/08] 下書き時にも自動通知メールが送信されるエラーを修正
  -      [2007/01/31] 画像添付の追加
  -      [2006/07/10] 作成
@@ -336,44 +337,22 @@ class webapp extends WAP_private
         if ($this->objmnp->getValue('status') != MESSAGE_SENT){
             return false;
         }
-        $this->send_mail();
+        $objmnp = new RKT_manip($this->objdb, DB_PREFIX.'fri_message');
 
-        $value = array(
-            'modify'=> $this->objmnp->getValue('modify'),
-            'regist_date'=> date('Y-m-d H:i:s'),
-            'ref_account'=> $this->objmnp->getValue('ref_to'),
-            'ref_to'=> $this->objmnp->getValue('ref_to'),
-            'ref_from'=> $this->objmnp->getValue('ref_from'),
-            'subject'=> $this->objmnp->getValue('subject'),
-            'body'=> $this->objmnp->getValue('body'),
-        );
+        $objmnp->setValue('modify',      date('Y-m-d H:i:s'));
+        $objmnp->setValue('regist_date', date('Y-m-d H:i:s'));
+        $objmnp->setValue('status',      MESSAGE_INBOX);
+        $objmnp->setValue('ref_account', $this->objmnp->getValue('ref_to'));
+        $objmnp->setValue('ref_to',      $this->objmnp->getValue('ref_to'));
+        $objmnp->setValue('ref_from',    $this->objmnp->getValue('ref_from'));
+        $objmnp->setValue('flag',        MESSAGE_FLAG_UNREAD);
+        $objmnp->setValue('subject',     $this->objmnp->getValue('subject'));
+        $objmnp->setValue('body',        $this->objmnp->getValue('body'));
 
-        $sql =
-            'INSERT INTO '.
-                DB_PREFIX.'fri_message('.
-                    'modify,'.
-                    'regist_date,'.
-                    'status,'.
-                    'ref_account,'.
-                    'ref_to,'.
-                    'ref_from,'.
-                    'flag,'.
-                    'subject,'.
-                    'body'.
-                ') VALUES ('.
-                    "'".$value['modify']."',".
-                    "'".$value['regist_date']."',".
-                    MESSAGE_INBOX.','.
-                    $value['ref_account'].','.
-                    $value['ref_to'].','.
-                    $value['ref_from'].','.
-                    MESSAGE_FLAG_UNREAD.','.
-                    "'".$value['subject']."',".
-                    "'".$value['body']."'".
-                ')';
-        $result = $this->objdb->exec($sql);
-        if ($result > 0){
-            $this->to_message_id = $this->objdb->lastInsertId();
+        $result = $objmnp->manip();
+        if ($result){
+            $this->send_mail();
+            $this->to_message_id = $objmnp->getCurID();
         }
         
         return $result;
@@ -395,9 +374,9 @@ class webapp extends WAP_private
         $sql =
             'UPDATE '.
                 DB_PREFIX.'fri_message '.
-            ' SET '.
+            'SET '.
                 'flag='.MESSAGE_FLAG_RETURN.' '.
-            ' WHERE '.
+            'WHERE '.
                 'ref_account ='.$this->account['id'].' AND '.
                 'id = '.$ref_message;
         return $this->objdb->exec($sql);
