@@ -188,7 +188,15 @@ class webapp extends WAP_public
 
         /* GROUP BY */
         if (!empty($this->table)){
-            $this->group = 'GROUP BY com.id ';
+            $this->group = 'GROUP BY '.
+                'com.id,'.
+                'com.community,'.
+                'com.total,'.
+                'com.publicity,'.
+                'prf.prefecture,'.
+                'pic.thumbnail,'.
+                'pic.t_width,'.
+                'pic.t_height ';
         }
 
         /* 並び替え */
