@@ -324,7 +324,16 @@ class webapp extends WAP_public
 
         /* GROUP BY */
         if (!empty($this->table)){
-            $this->group = 'GROUP BY act.id ';
+            $this->group = 'GROUP BY '.
+                'act.id,'.
+                'act.last_login,'.
+                'pro.nickname,'.
+                'act.friend_number,'.
+                'sex.sex,'.
+                'pht.thumbnail,'.
+                'pht.t_width,'.
+                'pht.t_height,'.
+                'pro.publicity '.
         }
 
         /* 並び替え */
