@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/08/07] 登録完了状態に推移しないエラーを修正
  -      [2007/06/17] last_loginの初期値指定を修正（コタ様より回避方法を頂きました）
  -      [2007/01/21] テーブルを fri_friends から fri_invite に変更
  -      [2006/08/29] メール送信時の送信先アドレス取得方法を修正
@@ -174,87 +175,53 @@ class webapp extends WAP_public
      */
     function query_profile()
     {
+        $ref_account = $this->objmnp->getCurID();
+        $sql=
+            'SELECT '.
+                'id '.
+                'ref_friend '.
+            'FROM '.
+                DB_PREFIX.'act_profile '.
+            'WHERE '.
+                'ref_account = '.$ref_account;
+        $stmt = $this->objdb->prepare($sql); 
+        $stmt->execute(); 
+        $result = $stmt->fetch(PDO_FETCH_ASSOC);
+        $stmt->closeCursor();
+
+        $objmnp = new RKT_manip($this->objdb, DB_PREFIX.'act_profile');
+        if (!empty($result['id'])){
+            $objmnp->setCurID($result['id']);
+        }
+
         $first_name  = $_SESSION[DB_PREFIX.'act_account']['first_name'];
         $second_name = $_SESSION[DB_PREFIX.'act_account']['second_name'];
         $nickname    = $_SESSION[DB_PREFIX.'act_account']['nickname'];
-
         $first_name  = sql_query::encrypt($first_name);
         $second_name = sql_query::encrypt($second_name);
 
-        $values = array(
-            'ref_account'=> $this->objmnp->getCurID(),
-            'modify'=> $this->objdb->quote(date('Y-m-d H:i:s')),
-            'first_name'=> $this->objdb->quote($first_name),
-            'second_name'=> $this->objdb->quote($second_name),
-            'name_flag'=> VISIBILITY_HIDDEN,
-            'nickname'=> $this->objdb->quote($nickname),
-            'visibility'=> VISIBILITY_PROTECTED,
-            'ref_prefecture'=> '49',                                // その他
-            'ref_local'=> '0',                                      // 
-            'prefecture_flag'=> VISIBILITY_HIDDEN,
-            'ref_sex'=> '3',                                        // 未記入
-            'sex_flag'=> VISIBILITY_HIDDEN,
-            'ref_blood'=> '5',                                      // 不明
-            'blood_flag'=> VISIBILITY_HIDDEN,
-            'birthday'=> $this->objdb->quote(date('Y-m-d H:i:s')),
-            'birthday_flag'=> VISIBILITY_HIDDEN,
-            'age_flag'=> VISIBILITY_HIDDEN,
-            'ref_married'=> '1',                                    // 無回答
-            'married_flag'=> VISIBILITY_HIDDEN,
-            'ref_hometown'=> 'NULL',
-            'ref_homelocal'=> 'NULL',
-            'hometown_flag'=> VISIBILITY_HIDDEN,
-            'publicity'=> 'NULL',
-        );
+        $objmnp->setValue('ref_account',    $ref_account);
+        $objmnp->setValue('modify',         date('Y-m-d H:i:s'));
+        $objmnp->setValue('first_name',     $first_name);
+        $objmnp->setValue('second_name',    $second_name);
+        $objmnp->setValue('name_flag',      VISIBILITY_HIDDEN);
+        $objmnp->setValue('nickname',       $nickname);
+        $objmnp->setValue('visibility',     VISIBILITY_PROTECTED);
+        $objmnp->setValue('ref_prefecture', '49');                  // その他
+        $objmnp->setValue('ref_local',      '0');                   // 
+        $objmnp->setValue('prefecture_flag',VISIBILITY_HIDDEN);
+        $objmnp->setValue('ref_sex',        '3');                   // 未記入
+        $objmnp->setValue('sex_flag',       VISIBILITY_HIDDEN);
+        $objmnp->setValue('ref_blood',      '5');                   // 不明
+        $objmnp->setValue('blood_flag',     VISIBILITY_HIDDEN);
+        $objmnp->setValue('birthday',       date('Y-m-d H:i:s'));
+        $objmnp->setValue('birthday_flag',  VISIBILITY_HIDDEN);
+        $objmnp->setValue('age_flag',       VISIBILITY_HIDDEN);
+        $objmnp->setValue('ref_married',    '1');                   // 無回答
+        $objmnp->setValue('married_flag',   VISIBILITY_HIDDEN);
+        $objmnp->setValue('hometown_flag',  VISIBILITY_HIDDEN);
 
-        /* 更新・挿入処理 */
-        $result = $this->__update_profile($values);
-        if (!$result){
-            $result = $this->__insert_profile($values);
-        }
-        return $result;
-    }
-
-    /**
-     * プロフィールの挿入
-     *
-     * @access private
-     * @param array $values
-     * @return boolean  真偽値
-     */
-    function __insert_profile($values)
-    {
-        $keys   = array_keys($values);
-        $column = implode(',',$keys);
-        $value  = implode(',',$values);
-
-        $sql =
-            'INSERT INTO '.
-                DB_PREFIX.'act_profile('.$column.')'.
-                ' VALUES ('.$value.')';
-        return $this->objdb->exec($sql);
-    }
-
-    /**
-     * プロフィールの更新
-     *
-     * @access private
-     * @param array $values
-     * @return boolean  真偽値
-     */
-    function __update_profile($values)
-    {
-        $sql = 
-            'UPDATE '.
-                DB_PREFIX.'act_profile '.
-            'SET '.
-                'modify = '.$values['modify'].','.
-                'first_name = '.$values['first_name'].','.
-                'second_name = '.$values['second_name'].','.
-                'nickname = '.$values['nickname'].' '.
-            'WHERE '.
-                'ref_account = '.$values['ref_account'];
-        return $this->objdb->exec($sql);
+        return $objmnp->manip();
     }
 
     /**
@@ -295,6 +262,7 @@ class webapp extends WAP_public
         $stmt = $this->objdb->prepare($sql); 
         $stmt->execute(); 
         $result = $stmt->fetch(PDO_FETCH_ASSOC);
+        $stmt->closeCursor();
         
     	$seed = md5($result['ref_account'].RKT_SEED);
         $seed = substr($seed,4,6);
