@@ -743,7 +743,7 @@ $webapp->execute();
 <html lang="ja">
 	<head>
 		<meta http-equiv="content-type" content='text/html; charset="utf-8"' />
-		<title>rktSNSセットアップ</title>
+		<title>ステップ２：rktSNSセットアップ</title>
 		<link rel="stylesheet" href="./resource/css/common.css" />
 		<link rel="stylesheet" href="./resource/css/admin.css" />
         <style media="screen" type="text/css">
@@ -782,15 +782,13 @@ $webapp->execute();
 		<div id="content">
 <!-- start:オペレーション領域 -->
 <div id="operation"> 
-    <h1>ステップ２</h1>
-
 	<!-- start:丸角 -->
 	<div class="round"> 
 		<div class="round1"><span></span></div><div class="round2"><span></span></div>
 		<div class="round3"></div><div class="round4"></div><div class="round5"></div> 
 	</div>
 	<div class="round_content">
-		<div class="column"><h2>環境設定</h2></div>
+		<div class="column"><h2>ステップ２：環境設定</h2></div>
 		<!-- start:アクション -->
 		<div class="formlist">
 			<form name="edit" method="post" action="<?php echo $_SERVER['PHP_SELF']; ?>">
@@ -807,28 +805,28 @@ $webapp->execute();
 				<div class="formrow"><strong>サイト情報URL</strong></div>
 				<div class="formrow">
 					<label class="column">管理者メールアドレス：</label>
-					<div>
+					<div class="fdata">
                         <span class="alert"><?php echo empty($GLOBALS['alert']['wap_administrator'])?'':'入力エラー<br />'; ?></span>
                         <input type="text" name="wap_administrator" value="<?php setValue('wap_administrator'); ?>" size="60" />
 					</div>
 				</div>
 				<div class="formrow">
 					<label class="column">システム名：</label>
-					<div>
+					<div class="fdata">
                         <span class="alert"><?php echo empty($GLOBALS['alert']['wap_system_name'])?'':'入力エラー<br />'; ?></span>
                         <input type="text" name="wap_system_name" value="<?php setValue('wap_system_name'); ?>" size="60" />
 					</div>
 				</div>
 				<div class="formrow">
 					<label class="column">制作著作：</label>
-					<div>
+					<div class="fdata">
                         <span class="alert"><?php echo empty($GLOBALS['alert']['copyright'])?'':'入力エラー<br />'; ?></span>
                         <input type="text" name="copyright" value="<?php setValue('copyright'); ?>" size="60" />
 					</div>
 				</div>
 				<div class="formrow">
 					<label class="column">招待制度:</label>
-					<div>
+					<div class="fdata">
                         <span class="alert"><?php echo empty($GLOBALS['alert']['wap_invite'])?'':'入力エラー<br />'; ?></span>
                         <input type="radio" name="wap_invite" value="1" id="wap_invite1"<?php checked('wap_invite',1); ?> />
 						<label for="wap_invite1">招待制</label>&nbsp;
@@ -838,7 +836,7 @@ $webapp->execute();
 				</div>
 				<div class="formrow">
 					<label class="column">日記のPDF:</label>
-					<div>
+					<div class="fdata">
                         <span class="alert"><?php echo empty($GLOBALS['alert']['wap_pdf_support'])?'':'入力エラー<br />'; ?></span>
                         <input type="radio" name="wap_pdf_support" value="1" id="wap_pdf_support1"<?php checked('wap_pdf_support',1); ?> />
 						<label for="wap_pdf_support1">PDFの生成を許可する</label>&nbsp;
@@ -850,14 +848,14 @@ $webapp->execute();
 				<div class="formrow"><strong>サイトURL</strong></div>
 				<div class="formrow">
 					<label class="column">クッキー発行ドメイン：</label>
-					<div>
+					<div class="fdata">
                         <span class="alert"><?php echo empty($GLOBALS['alert']['wap_cookie_domain'])?'':'入力エラー<br />'; ?></span>
                         <input type="text" name="wap_cookie_domain" value="<?php setValue('wap_cookie_domain'); ?>" size="60" />
 					</div>
 				</div>
 				<div class="formrow">
 					<label class="column">ベースURL：</label>
-					<div>
+					<div class="fdata">
                         <span class="alert"><?php echo empty($GLOBALS['alert']['base_url'])?'':'入力エラー<br />'; ?></span>
                         <input type="text" name="base_url" value="<?php if (!empty($GLOBALS['base_url'])){ echo $GLOBALS['base_url']; } else { setValue('base_url'); } ?>" size="60" /><br />
                         exec.phpのあるパスを指定下さい。<br />
@@ -866,7 +864,7 @@ $webapp->execute();
 				</div>
 				<div class="formrow">
 					<label class="column">SSLURL：</label>
-					<div>
+					<div class="fdata">
                         <span class="alert"><?php echo empty($GLOBALS['alert']['ssl_url'])?'':'入力エラー<br />'; ?></span>
                         <input type="text" name="ssl_url" value="<?php if (!empty($GLOBALS['ssl_url'])){ echo $GLOBALS['ssl_url']; } else {  setValue('ssl_url'); } ?>" size="60" /><br />
                         exec.phpのあるパスを指定下さい。<br />
@@ -876,7 +874,7 @@ $webapp->execute();
 				</div>
 				<div class="formrow">
 					<label class="column">URLの表記について<br />(PathInfo):</label>
-					<div>
+					<div class="fdata">
                         <span class="alert"><?php echo empty($GLOBALS['alert']['path_info_key'])?'':'入力エラー<br />'; ?></span>
                         <input type="radio" name="path_info_key" value="QUERY_STRING" id="path_info_key0"<?php checked('path_info_key','QUERY_STRING'); ?> />
 						<label for="path_info_key0">PathInfo無効</label>：exec.phpの様に拡張子が表示されます。<br />
@@ -890,7 +888,7 @@ $webapp->execute();
 				<div class="formrow"><strong>データベース</strong></div>
 				<div class="formrow">
 					<label class="column">データベースドライバ：</label>
-					<div>
+					<div class="fdata">
                         <span class="alert"><?php echo empty($GLOBALS['alert']['wap_db_driver'])?'':'入力エラー<br />'; ?></span>
                         <input type="radio" name="wap_db_driver" value="sqlite" id="wap_db_driver1"<?php checked('wap_db_driver','sqlite'); ?> />
 						<label for="wap_db_driver1">SQLite</label>&nbsp;
@@ -902,35 +900,35 @@ $webapp->execute();
 				</div>
 				<div class="formrow">
 					<label class="column">データベース名：</label>
-					<div>
+					<div class="fdata">
                         <span class="alert"><?php echo empty($GLOBALS['alert']['wap_db_name'])?'':'入力エラー<br />'; ?></span>
                         <input type="text" name="wap_db_name" value="<?php setValue('wap_db_name'); ?>" size="60" />
 					</div>
 				</div>
 				<div class="formrow">
 					<label class="column">ホスト：</label>
-					<div>
+					<div class="fdata">
                         <span class="alert"><?php echo empty($GLOBALS['alert']['wap_db_host'])?'':'入力エラー<br />'; ?></span>
                         <input type="text" name="wap_db_host" value="<?php setValue('wap_db_host'); ?>" size="60" />
 					</div>
 				</div>
 				<div class="formrow">
 					<label class="column">ユーザー名：</label>
-					<div>
+					<div class="fdata">
                         <span class="alert"><?php echo empty($GLOBALS['alert']['wap_db_user'])?'':'入力エラー<br />'; ?></span>
                         <input type="text" name="wap_db_user" value="<?php setValue('wap_db_user'); ?>" size="60" />
 					</div>
 				</div>
 				<div class="formrow">
 					<label class="column">パスワード：</label>
-					<div>
+					<div class="fdata">
                         <span class="alert"><?php echo empty($GLOBALS['alert']['wap_db_passwd'])?'':'入力エラー<br />'; ?></span>
                         <input type="text" name="wap_db_passwd" value="<?php setValue('wap_db_passwd'); ?>" size="60" />
 					</div>
 				</div>
 				<div class="formrow">
 					<label class="column">MySQLバージョン：</label>
-					<div>
+					<div class="fdata">
                         <span class="alert"><?php echo empty($GLOBALS['alert']['use_set_names'])?'':'入力エラー<br />'; ?></span>
                         <input type="radio" name="use_set_names" value="0" id="use_set_names1"<?php checked('use_set_names','0'); ?> />
 						<label for="use_set_names1">MySQL4.1未満</label>&nbsp;&nbsp;&nbsp;
@@ -943,14 +941,14 @@ $webapp->execute();
 				<div class="formrow"><strong>暗号など</strong></div>
 				<div class="formrow">
 					<label class="column">暗号等に使われる種：</label>
-					<div>
+					<div class="fdata">
                         <span class="alert"><?php echo empty($GLOBALS['alert']['wap_pass_seed'])?'':'入力エラー<br />'; ?></span>
                         <input type="text" name="wap_pass_seed" value="<?php setValue('wap_pass_seed'); ?>" size="60" />
 					</div>
 				</div>
 				<div class="formrow">
 					<label class="column">パスフレーズ：</label>
-					<div>
+					<div class="fdata">
                         <span class="alert"><?php echo empty($GLOBALS['alert']['wap_pass_phrase'])?'':'入力エラー<br />'; ?></span>
                         <input type="text" name="wap_pass_phrase" value="<?php setValue('wap_pass_phrase'); ?>" size="60" />
 					</div>
@@ -959,7 +957,7 @@ $webapp->execute();
 				<div class="formrow"><strong>アマゾンアソシエーションサービス</strong></div>
 				<div class="formrow">
 					<label class="column">アクセスID：</label>
-					<div>
+					<div class="fdata">
                         <span class="alert"><?php echo empty($GLOBALS['alert']['amazon_associateid'])?'':'入力エラー<br />'; ?></span>
                         <input type="text" name="amazon_associateid" value="<?php setValue('amazon_associateid'); ?>" size="60" />
 					</div>
@@ -967,14 +965,14 @@ $webapp->execute();
 				<div class="formrow"><strong>画像処理</strong></div>
 				<div class="formrow">
 					<label class="column">imagemagickのパス：</label>
-					<div>
+					<div class="fdata">
                         <span class="alert"><?php echo empty($GLOBALS['alert']['imagemagick_path'])?'':'入力エラー<br />'; ?></span>
                         <input type="text" name="imagemagick_path" value="<?php setValue('imagemagick_path'); ?>" size="60" />
 					</div>
 				</div>
 				<div class="formrow">
 					<label class="column">画像加工ドライバ:</label>
-					<div>
+					<div class="fdata">
                         <span class="alert"><?php echo empty($GLOBALS['alert']['image_driver'])?'':'入力エラー<br />'; ?></span>
                         <input type="radio" name="image_driver" value="gd" id="image_driver1"<?php checked('image_driver','gd'); ?> />
 						<label for="image_driver1">GD</label>&nbsp;
@@ -986,35 +984,36 @@ $webapp->execute();
 				<div class="formrow"><strong>インポート用メール設定</strong></div>
 				<div class="formrow">
 					<label class="column">インポート用メール：</label>
-					<div class="fdata">{if $alert.action_mail}<span class="alert">入力してください。</span><br />{/if}
-						<input type="text" name="action_mail" value="{$value.action_mail|default:$smarty.const.ACTION_MAIL}" size="60" /><br />
-						携帯ページで画像投稿用に使われます。<br />
+					<div class="fdata">
+                        <span class="alert"><?php echo empty($GLOBALS['alert']['action_mail'])?'':'入力してください<br />'; ?></span>
+                        <input type="text" name="action_mail" value="<?php setValue('action_mail'); ?>" size="60" /><br />
+                        <span class="alert">携帯ページで画像投稿用に使われます。</span><br />
 					</div>
 				</div>
 				<div class="formrow">
 					<label class="column">POP3ホスト：</label>
-					<div>
+					<div class="fdata">
                         <span class="alert"><?php echo empty($GLOBALS['alert']['pop3_host'])?'':'入力エラー<br />'; ?></span>
                         <input type="text" name="pop3_host" value="<?php setValue('pop3_host'); ?>" size="60" />
 					</div>
 				</div>
 				<div class="formrow">
 					<label class="column">POP3アカウント：</label>
-					<div>
+					<div class="fdata">
                         <span class="alert"><?php echo empty($GLOBALS['alert']['pop3_account'])?'':'入力エラー<br />'; ?></span>
                         <input type="text" name="pop3_account" value="<?php setValue('pop3_account'); ?>" size="60" />
 					</div>
 				</div>
 				<div class="formrow">
 					<label class="column">POP3パスワード：</label>
-					<div>
+					<div class="fdata">
                         <span class="alert"><?php echo empty($GLOBALS['alert']['pop3_password'])?'':'入力エラー<br />'; ?></span>
                         <input type="text" name="pop3_password" value="<?php setValue('pop3_password'); ?>" size="60" />
 					</div>
 				</div>
 				<div class="formrow">
 					<label class="column">メールボックスパス：</label>
-					<div>
+					<div class="fdata">
                         <span class="alert"><?php echo empty($GLOBALS['alert']['mail_box_dir'])?'':'入力エラー<br />'; ?></span>
                         <input type="text" name="mail_box_dir" value="<?php setValue('mail_box_dir'); ?>" size="60" />
 					</div>
