@@ -343,7 +343,7 @@ $webapp->execute();
 <html lang="ja">
 	<head>
 		<meta http-equiv="content-type" content='text/html; charset="utf-8"' />
-		<title>rktSNSセットアップ</title>
+		<title>データベースの初期設定：rktSNSセットアップ</title>
 		<link rel="stylesheet" href="./resource/css/common.css" />
 		<link rel="stylesheet" href="./resource/css/admin.css" />
         <style media="screen" type="text/css">
@@ -424,8 +424,6 @@ $webapp->execute();
 		<div id="content">
 <!-- start:オペレーション領域 -->
 <div id="operation"> 
-    <h1>データベースの初期設定</h1>
-
 	<!-- start:丸角 -->
 	<div class="round"> 
 		<div class="round1"><span></span></div><div class="round2"><span></span></div>
@@ -440,7 +438,7 @@ $webapp->execute();
 				<div class="formrow"><strong>作業レベル</strong></div>
 				<div class="formrow">
 					<label class="column">テーブルの作成：</label>
-					<div>
+					<div class="fdata">
         				<div class="progress" style="width:300px">
         					<div id="bar_1_1" class="bar" style="border-left: 2px solid white;"></div><div id="bar_1_2" class="bar"></div>
         					<div id="bar_1_3" class="bar"></div><div id="bar_1_4" class="bar"></div>
@@ -478,7 +476,7 @@ $webapp->execute();
 				</div>
 				<div class="formrow">
 					<label class="column">データの生成：</label>
-					<div>
+					<div class="fdata">
         				<div class="progress" style="width:300px">
         					<div id="bar_2_1" class="bar" style="border-left: 2px solid white;"></div><div id="bar_2_2" class="bar"></div>
         					<div id="bar_2_3" class="bar"></div><div id="bar_2_4" class="bar"></div>
@@ -516,7 +514,7 @@ $webapp->execute();
 				</div>
 				<div class="formrow">
 					<label class="column">インデックスの生成：</label>
-					<div>
+					<div class="fdata">
         				<div class="progress" style="width:300px">
         					<div id="bar_3_1" class="bar" style="border-left: 2px solid white;"></div><div id="bar_3_2" class="bar"></div>
         					<div id="bar_3_3" class="bar"></div><div id="bar_3_4" class="bar"></div>
