@@ -20,6 +20,7 @@
 --      yujiro@rakuto.net
 --      http://rakuto.net/rktSNS/
 -- 更新履歴：
+--	[2007/08/13] 会員メールアクション追加
 --      [2007/06/17] コミュニティ：アクセスログ・あしあと追加
 --      [2007/04/21] 問合せ内容・問合せ対応インデックス追加
 --      [2007/03/23] お友達の招待インデックス追加
@@ -47,6 +48,11 @@ CREATE INDEX sns_autologin_account ON sns_act_autologin (ref_account);
 CREATE INDEX sns_account_login ON sns_act_account (last_login);
 CREATE INDEX sns_account_number ON sns_act_account (friend_number);
 
+-- 
+-- 会員メールアクション
+-- 
+CREATE INDEX sns_mailaction_modify ON sns_act_mailaction (modify);
+
 -- 
 -- 会員プロフィール
 -- 
