@@ -255,14 +255,9 @@ INSERT INTO sns_sys_mailtpl VALUES('18','2006-07-22 05:35:11','auto_invite','新
 招待メールを送信させて頂きました。
 
 下記URLを開き是非、ご参加ください。
-[PC用 URL]
 {$url}
 
 
-[携帯用 URL]
-{$mobile_url}
-
-
 確定ページが正しく表示されない場合
 　セキュリティのため、URLが長く設定されています。
 　お使いのメールソフトによっては、URLが2行以上で表示される場合があります。
