@@ -20,6 +20,7 @@
 --      yujiro@rakuto.net
 --      http://rakuto.net/rktSNS/
 -- 更新履歴：
+--	[2007/08/30] 会員メールアクションref_communityをref_additionに変更
 --	[2007/08/13] 会員メールアクション追加
 --	[2007/08/05] レビューの対象商品の必須項目を緩和
 --      [2007/07/05] 日記設定：sns_dia_diary.visibilityを削除
@@ -235,7 +236,7 @@ CREATE TABLE 'sns_act_mailaction' (
   'ref_table' integer NOT NULL,
   'ref_relation' integer NOT NULL,
   'ref_account' integer NOT NULL,
-  'ref_community' integer,
+  'ref_addition'  integer,
   PRIMARY KEY  ('id'),
   UNIQUE ('ref_table', 'ref_relation', 'ref_account')
 );
