@@ -20,21 +20,12 @@
 --      yujiro@rakuto.net
 --      http://rakuto.net/rktSNS/
 -- 更新履歴：
---	[2007/08/13] 会員メールアクション追加
+--	[2007/08/30] 会員メールアクションref_communityをref_additionに変更
 -- ========================================================================
 
 -- --------------------------------------------------------
 -- 
 -- 会員メールアクション
 -- 
-CREATE TABLE `sns_act_mailaction` (
-  `id` int(11) unsigned NOT NULL auto_increment,
-  `modify` timestamp NOT NULL,
-  `ref_table` int(11) NOT NULL,
-  `ref_relation` int(11) NOT NULL,
-  `ref_account` int(11) NOT NULL,
-  `ref_community` int(11),
-  PRIMARY KEY  (`id`),
-  UNIQUE (`ref_table`, `ref_relation`, `ref_account`)
-) ENGINE=MyISAM AUTO_INCREMENT=1 DEFAULT CHARSET=utf8;
+ALTER TABLE `sns_act_mailaction` CHANGE `ref_community` `ref_addition` INT( 11 ) NULL DEFAULT NULL;
 
