@@ -20,21 +20,11 @@
 --      yujiro@rakuto.net
 --      http://rakuto.net/rktSNS/
 -- 更新履歴：
---	[2007/08/13] 会員メールアクション追加
+--	[2007/08/30] 会員メールアクションref_communityをref_additionに変更
 -- ========================================================================
 
 -- --------------------------------------------------------
 -- 
 -- 会員メールアクション
 -- 
-CREATE SEQUENCE seq_sns_act_mailaction start 1 increment 1 maxvalue 9223372036854775807 minvalue 1 cache 1;
-CREATE TABLE sns_act_mailaction (
-  "id" integer DEFAULT nextval('seq_sns_act_mailaction'::text) NOT NULL,
-  "modify" timestamp without time zone NOT NULL,
-  "ref_table" integer NOT NULL,
-  "ref_relation" integer NOT NULL,
-  "ref_account" integer NOT NULL,
-  "ref_community" integer,
-  PRIMARY KEY  (id),
-  UNIQUE (ref_table, ref_relation, ref_account)
-);
+ALTER TABLE sns_act_mailaction RENAME ref_community  TO ref_addition;
\ No newline at end of file
